# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_familygroups.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_familygroups.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\"H\n\'CFamilyGroups_CreateFamilyGroup_Request\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"a\n(CFamilyGroups_CreateFamilyGroup_Response\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x1d\n\x15\x63ooldown_skip_granted\x18\x02 \x01(\x08\"Y\n$CFamilyGroups_GetFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x19\n\x11send_running_apps\x18\x02 \x01(\x08\"\x97\x01\n\x11\x46\x61milyGroupMember\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x38\n\x04role\x18\x02 \x01(\x0e\x32\x11.EFamilyGroupRole:\x17k_EFamilyGroupRole_None\x12\x13\n\x0btime_joined\x18\x03 \x01(\r\x12\"\n\x1a\x63ooldown_seconds_remaining\x18\x04 \x01(\r\"e\n\x18\x46\x61milyGroupPendingInvite\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x38\n\x04role\x18\x02 \x01(\x0e\x32\x11.EFamilyGroupRole:\x17k_EFamilyGroupRole_None\"*\n\x17\x46\x61milyGroupFormerMember\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xaf\x02\n%CFamilyGroups_GetFamilyGroup_Response\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x07members\x18\x02 \x03(\x0b\x32\x12.FamilyGroupMember\x12\x32\n\x0fpending_invites\x18\x03 \x03(\x0b\x32\x19.FamilyGroupPendingInvite\x12\x12\n\nfree_spots\x18\x04 \x01(\r\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\'\n\x1fslot_cooldown_remaining_seconds\x18\x06 \x01(\r\x12\x30\n\x0e\x66ormer_members\x18\x07 \x03(\x0b\x32\x18.FamilyGroupFormerMember\x12\x1f\n\x17slot_cooldown_overrides\x18\x08 \x01(\r\"e\n+CFamilyGroups_GetFamilyGroupForUser_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12%\n\x1dinclude_family_group_response\x18\x02 \x01(\x08\"\xa2\x01\n\x1f\x46\x61milyGroupPendingInviteForUser\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x38\n\x04role\x18\x02 \x01(\x0e\x32\x11.EFamilyGroupRole:\x17k_EFamilyGroupRole_None\x12\x17\n\x0finviter_steamid\x18\x03 \x01(\x06\x12\x14\n\x0c\x61waiting_2fa\x18\x04 \x01(\x08\"\x86\x03\n,CFamilyGroups_GetFamilyGroupForUser_Response\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\"\n\x1ais_not_member_of_any_group\x18\x02 \x01(\x08\x12\x1a\n\x12latest_time_joined\x18\x03 \x01(\r\x12$\n\x1clatest_joined_family_groupid\x18\x04 \x01(\x04\x12?\n\x15pending_group_invites\x18\x05 \x03(\x0b\x32 .FamilyGroupPendingInviteForUser\x12\x0c\n\x04role\x18\x06 \x01(\r\x12\"\n\x1a\x63ooldown_seconds_remaining\x18\x07 \x01(\r\x12<\n\x0c\x66\x61mily_group\x18\x08 \x01(\x0b\x32&.CFamilyGroups_GetFamilyGroup_Response\x12\'\n\x1f\x63\x61n_undelete_last_joined_family\x18\t \x01(\x08\"V\n.CFamilyGroups_ModifyFamilyGroupDetails_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"1\n/CFamilyGroups_ModifyFamilyGroupDetails_Response\"\xa0\x01\n)CFamilyGroups_InviteToFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x18\n\x10receiver_steamid\x18\x02 \x01(\x06\x12\x41\n\rreceiver_role\x18\x03 \x01(\x0e\x32\x11.EFamilyGroupRole:\x17k_EFamilyGroupRole_None\"\x9d\x01\n*CFamilyGroups_InviteToFamilyGroup_Response\x12\x11\n\tinvite_id\x18\x01 \x01(\x04\x12\\\n\x11two_factor_method\x18\x02 \x01(\x0e\x32\x1d.EFamilyGroupsTwoFactorMethod:\"k_EFamilyGroupsTwoFactorMethodNone\"l\n0CFamilyGroups_ConfirmInviteToFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x11\n\tinvite_id\x18\x02 \x01(\x04\x12\r\n\x05nonce\x18\x03 \x01(\x04\"3\n1CFamilyGroups_ConfirmInviteToFamilyGroup_Response\"^\n3CFamilyGroups_ResendInvitationToFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\"6\n4CFamilyGroups_ResendInvitationToFamilyGroup_Response\"N\n%CFamilyGroups_JoinFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\r\n\x05nonce\x18\x02 \x01(\x04\"\xc6\x01\n&CFamilyGroups_JoinFamilyGroup_Response\x12\\\n\x11two_factor_method\x18\x02 \x01(\x0e\x32\x1d.EFamilyGroupsTwoFactorMethod:\"k_EFamilyGroupsTwoFactorMethodNone\x12\x1d\n\x15\x63ooldown_skip_granted\x18\x03 \x01(\x08\x12\x1f\n\x17invite_already_accepted\x18\x04 \x01(\x08\"h\n,CFamilyGroups_ConfirmJoinFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x11\n\tinvite_id\x18\x02 \x01(\x04\x12\r\n\x05nonce\x18\x03 \x01(\x04\"/\n-CFamilyGroups_ConfirmJoinFamilyGroup_Response\"`\n+CFamilyGroups_RemoveFromFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x19\n\x11steamid_to_remove\x18\x02 \x01(\x06\".\n,CFamilyGroups_RemoveFromFamilyGroup_Response\"b\n-CFamilyGroups_CancelFamilyGroupInvite_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x19\n\x11steamid_to_cancel\x18\x02 \x01(\x06\"0\n.CFamilyGroups_CancelFamilyGroupInvite_Response\"a\n+CFamilyGroups_GetUsersSharingDevice_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x1a\n\x12\x63lient_instance_id\x18\x02 \x01(\x04\"=\n,CFamilyGroups_GetUsersSharingDevice_Response\x12\r\n\x05users\x18\x01 \x03(\x06\"A\n\'CFamilyGroups_DeleteFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\"*\n(CFamilyGroups_DeleteFamilyGroup_Response\"C\n)CFamilyGroups_UndeleteFamilyGroup_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\",\n*CFamilyGroups_UndeleteFamilyGroup_Response\"B\n(CFamilyGroups_GetPlaytimeSummary_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x06\"\x82\x01\n\x1b\x43\x46\x61milyGroups_PlaytimeEntry\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x14\n\x0c\x66irst_played\x18\x03 \x01(\r\x12\x15\n\rlatest_played\x18\x04 \x01(\r\x12\x16\n\x0eseconds_played\x18\x05 \x01(\r\"\x92\x01\n)CFamilyGroups_GetPlaytimeSummary_Response\x12-\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1c.CFamilyGroups_PlaytimeEntry\x12\x36\n\x10\x65ntries_by_owner\x18\x02 \x03(\x0b\x32\x1c.CFamilyGroups_PlaytimeEntry\"\x8e\x01\n%CFamilyGroups_RequestPurchase_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x17\n\x0fgidshoppingcart\x18\x02 \x01(\x04\x12\x1a\n\x12store_country_code\x18\x03 \x01(\t\x12\x18\n\x10use_account_cart\x18\x04 \x01(\x08\"U\n&CFamilyGroups_RequestPurchase_Response\x12\x17\n\x0fgidshoppingcart\x18\x01 \x01(\x04\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\"|\n)CFamilyGroups_GetPurchaseRequests_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x13\n\x0brequest_ids\x18\x03 \x03(\x04\x12\"\n\x1art_include_completed_since\x18\x04 \x01(\r\"\x81\x03\n\x0fPurchaseRequest\x12\x19\n\x11requester_steamid\x18\x01 \x01(\x06\x12\x17\n\x0fgidshoppingcart\x18\x02 \x01(\x04\x12\x16\n\x0etime_requested\x18\x03 \x01(\r\x12\x16\n\x0etime_responded\x18\x04 \x01(\r\x12\x19\n\x11responder_steamid\x18\x05 \x01(\x06\x12O\n\x0fresponse_action\x18\x06 \x01(\x0e\x32\x17.EPurchaseRequestAction:\x1dk_EPurchaseRequestAction_None\x12\x14\n\x0cis_completed\x18\x07 \x01(\x08\x12\x12\n\nrequest_id\x18\x08 \x01(\x04\x12\x1c\n\x14requested_packageids\x18\t \x03(\r\x12\x1c\n\x14purchased_packageids\x18\n \x03(\r\x12\x1b\n\x13requested_bundleids\x18\x0b \x03(\r\x12\x1b\n\x13purchased_bundleids\x18\x0c \x03(\r\"P\n*CFamilyGroups_GetPurchaseRequests_Response\x12\"\n\x08requests\x18\x01 \x03(\x0b\x32\x10.PurchaseRequest\"\xa6\x01\n0CFamilyGroups_RespondToRequestedPurchase_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x46\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x17.EPurchaseRequestAction:\x1dk_EPurchaseRequestAction_None\x12\x12\n\nrequest_id\x18\x04 \x01(\x04\"3\n1CFamilyGroups_RespondToRequestedPurchase_Response\"<\n\"CFamilyGroups_GetChangeLog_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\"\xf9\x01\n#CFamilyGroups_GetChangeLog_Response\x12<\n\x07\x63hanges\x18\x01 \x03(\x0b\x32+.CFamilyGroups_GetChangeLog_Response.Change\x1a\x93\x01\n\x06\x43hange\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\x15\n\ractor_steamid\x18\x02 \x01(\x06\x12=\n\x04type\x18\x03 \x01(\x0e\x32\x1a.EFamilyGroupChangeLogType:\x13k_InvalidChangeType\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x12\x12\n\nby_support\x18\x05 \x01(\x08\"b\n0CFamilyGroups_SetFamilyCooldownOverrides_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x16\n\x0e\x63ooldown_count\x18\x02 \x01(\r\"3\n1CFamilyGroups_SetFamilyCooldownOverrides_Response\"\xc3\x01\n*CFamilyGroups_GetSharedLibraryApps_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x06\x12\x13\n\x0binclude_own\x18\x02 \x01(\x08\x12\x18\n\x10include_excluded\x18\x03 \x01(\x08\x12\x10\n\x08language\x18\x05 \x01(\t\x12\x10\n\x08max_apps\x18\x06 \x01(\r\x12\x19\n\x11include_non_games\x18\x07 \x01(\x08\x12\x0f\n\x07steamid\x18\x08 \x01(\x06\"\xf6\x03\n+CFamilyGroups_GetSharedLibraryApps_Response\x12\x44\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x36.CFamilyGroups_GetSharedLibraryApps_Response.SharedApp\x12\x15\n\rowner_steamid\x18\x02 \x01(\x06\x1a\xe9\x02\n\tSharedApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0eowner_steamids\x18\x02 \x03(\x06\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07sort_as\x18\x07 \x01(\t\x12\x18\n\x10\x63\x61psule_filename\x18\x08 \x01(\t\x12\x15\n\rimg_icon_hash\x18\t \x01(\t\x12O\n\x0e\x65xclude_reason\x18\n \x01(\x0e\x32\x1c.ESharedLibraryExcludeReason:\x19k_ESharedLibrary_Included\x12\x18\n\x10rt_time_acquired\x18\x0b \x01(\r\x12\x16\n\x0ert_last_played\x18\x0c \x01(\r\x12\x13\n\x0brt_playtime\x18\r \x01(\r\x12\x30\n\x08\x61pp_type\x18\x0e \x01(\x0e\x32\x0e.EProtoAppType:\x0ek_EAppTypeGame\x12\x1b\n\x13\x63ontent_descriptors\x18\x0f \x03(\r\"i\n(CFamilyGroups_SetPreferredLender_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x16\n\x0elender_steamid\x18\x03 \x01(\x06\"+\n)CFamilyGroups_SetPreferredLender_Response\"C\n)CFamilyGroups_GetPreferredLenders_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\"\xb2\x01\n*CFamilyGroups_GetPreferredLenders_Response\x12I\n\x07members\x18\x01 \x03(\x0b\x32\x38.CFamilyGroups_GetPreferredLenders_Response.FamilyMember\x1a\x39\n\x0c\x46\x61milyMember\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10preferred_appids\x18\x02 \x03(\r\"R\n\'CFamilyGroups_ForceAcceptInvite_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"*\n(CFamilyGroups_ForceAcceptInvite_Response\"V\n+CFamilyGroups_GetInviteCheckResults_Request\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"z\n,CFamilyGroups_GetInviteCheckResults_Response\x12\x1e\n\x16wallet_country_matches\x18\x01 \x01(\x08\x12\x10\n\x08ip_match\x18\x02 \x01(\x08\x12\x18\n\x10join_restriction\x18\x03 \x01(\r\"M\n\'CFamilyGroups_ClearCooldownSkip_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tinvite_id\x18\x02 \x01(\x04\"*\n(CFamilyGroups_ClearCooldownSkip_Response\"\xdb\x02\n2CFamilyGroupsClient_NotifyRunningApps_Notification\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04\x12T\n\x0crunning_apps\x18\x02 \x03(\x0b\x32>.CFamilyGroupsClient_NotifyRunningApps_Notification.RunningApp\x1a>\n\rPlayingMember\x12\x16\n\x0emember_steamid\x18\x01 \x01(\x06\x12\x15\n\rowner_steamid\x18\x02 \x01(\x06\x1aw\n\nRunningApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12Z\n\x0fplaying_members\x18\x03 \x03(\x0b\x32\x41.CFamilyGroupsClient_NotifyRunningApps_Notification.PlayingMember\"/\n-CFamilyGroupsClient_InviteStatus_Notification\"G\n-CFamilyGroupsClient_GroupChanged_Notification\x12\x16\n\x0e\x66\x61mily_groupid\x18\x01 \x01(\x04*\x87\x01\n\x10\x45\x46\x61milyGroupRole\x12\x1b\n\x17k_EFamilyGroupRole_None\x10\x00\x12\x1c\n\x18k_EFamilyGroupRole_Adult\x10\x01\x12\x1c\n\x18k_EFamilyGroupRole_Child\x10\x02\x12\x1a\n\x16k_EFamilyGroupRole_MAX\x10\x03*\x99\x01\n\x1c\x45\x46\x61milyGroupsTwoFactorMethod\x12&\n\"k_EFamilyGroupsTwoFactorMethodNone\x10\x00\x12(\n$k_EFamilyGroupsTwoFactorMethodMobile\x10\x01\x12\'\n#k_EFamilyGroupsTwoFactorMethodEmail\x10\x02*\xf8\x01\n\x16\x45PurchaseRequestAction\x12!\n\x1dk_EPurchaseRequestAction_None\x10\x00\x12$\n k_EPurchaseRequestAction_Decline\x10\x01\x12&\n\"k_EPurchaseRequestAction_Purchased\x10\x02\x12&\n\"k_EPurchaseRequestAction_Abandoned\x10\x03\x12#\n\x1fk_EPurchaseRequestAction_Cancel\x10\x04\x12 \n\x1ck_EPurchaseRequestAction_MAX\x10\x05*\x88\x06\n\x19\x45\x46\x61milyGroupChangeLogType\x12\x17\n\x13k_InvalidChangeType\x10\x00\x12\x18\n\x14k_FamilyGroupCreated\x10\x01\x12\x19\n\x15k_FamilyGroupModified\x10\x02\x12\x18\n\x14k_FamilyGroupDeleted\x10\x03\x12\x14\n\x10k_AccountInvited\x10\x04\x12\x1d\n\x19k_InviteDeniedByGroupSize\x10\x05\x12\x17\n\x13k_JoinedFamilyGroup\x10\x06\x12 \n\x1ck_JoinDeniedByRegionMismatch\x10\x07\x12\"\n\x1ek_JoinDeniedByMissingIpAddress\x10\x08\x12 \n\x1ck_JoinDeniedByFamilyCooldown\x10\t\x12\x1e\n\x1ak_JoinDeniedByUserCooldown\x10\n\x12\x1c\n\x18k_JoinDeniedByOtherGroup\x10\x0b\x12\x14\n\x10k_AccountRemoved\x10\x0c\x12\x14\n\x10k_InviteCanceled\x10\r\x12\x17\n\x13k_PurchaseRequested\x10\x0e\x12\x1d\n\x19k_ParentalSettingsEnabled\x10\x0f\x12\x1e\n\x1ak_ParentalSettingsDisabled\x10\x10\x12\x1d\n\x19k_ParentalSettingsChanged\x10\x11\x12$\n k_FamilyCooldownOverridesChanged\x10\x12\x12\x1d\n\x19k_PurchaseRequestCanceled\x10\x13\x12\x1d\n\x19k_PurchaseRequestApproved\x10\x14\x12\x1d\n\x19k_PurchaseRequestDeclined\x10\x15\x12\x1a\n\x16k_CooldownSkipConsumed\x10\x16\x12\x19\n\x15k_FamilyGroupRestored\x10\x17\x12\x10\n\x0ck_JoinDenied\x10\x18\x12 \n\x1ck_SupportForceAcceptedInvite\x10\x19*\x9c\x0b\n\x1b\x45SharedLibraryExcludeReason\x12\x1d\n\x19k_ESharedLibrary_Included\x10\x00\x12*\n&k_ESharedLibrary_AppExcluded_ByPartner\x10\x01\x12$\n k_ESharedLibrary_LicenseExcluded\x10\x02\x12\x1d\n\x19k_ESharedLibrary_FreeGame\x10\x03\x12#\n\x1fk_ESharedLibrary_LicensePrivate\x10\x04\x12-\n)k_ESharedLibrary_AppExcluded_WrongAppType\x10\x06\x12\x31\n-k_ESharedLibrary_AppExcluded_NonrefundableDLC\x10\x07\x12.\n*k_ESharedLibrary_AppExcluded_UnreleasedApp\x10\x08\x12\x32\n.k_ESharedLibrary_AppExcluded_ParentAppExcluded\x10\t\x12.\n*k_ESharedLibrary_PackageExcluded_ByPartner\x10\n\x12,\n(k_ESharedLibrary_PackageExcluded_Special\x10\x0b\x12(\n$k_ESharedLibrary_PackageExcluded_Dev\x10\x0c\x12\x30\n,k_ESharedLibrary_PackageExcluded_FreeWeekend\x10\r\x12,\n(k_ESharedLibrary_PackageExcluded_Invalid\x10\x0f\x12\x35\n1k_ESharedLibrary_PackageExcluded_RecurringLicense\x10\x10\x12\x35\n1k_ESharedLibrary_PackageExcluded_WrongLicenseType\x10\x11\x12.\n*k_ESharedLibrary_PackageExcluded_MasterSub\x10\x12\x12\x34\n0k_ESharedLibrary_PackageExcluded_NoShareableApps\x10\x13\x12\x35\n1k_ESharedLibrary_LicenseExcluded_PaymentMasterSub\x10\x14\x12\x37\n3k_ESharedLibrary_LicenseExcluded_PaymentFamilyGroup\x10\x15\x12<\n8k_ESharedLibrary_LicenseExcluded_PaymentAuthorizedDevice\x10\x16\x12\x35\n1k_ESharedLibrary_LicenseExcluded_PaymentAutoGrant\x10\x17\x12\x30\n,k_ESharedLibrary_LicenseExcluded_FlagPending\x10\x18\x12\x36\n2k_ESharedLibrary_LicenseExcluded_FlagPendingRefund\x10\x19\x12\x31\n-k_ESharedLibrary_LicenseExcluded_FlagBorrowed\x10\x1a\x12\x32\n.k_ESharedLibrary_LicenseExcluded_FlagAutoGrant\x10\x1b\x12\x33\n/k_ESharedLibrary_LicenseExcluded_FlagTimedTrial\x10\x1c\x12,\n(k_ESharedLibrary_LicenseExcluded_FreeSub\x10\x1d\x12-\n)k_ESharedLibrary_LicenseExcluded_Inactive\x10\x1e\x32\xb4\x17\n\x0c\x46\x61milyGroups\x12h\n\x11\x43reateFamilyGroup\x12(.CFamilyGroups_CreateFamilyGroup_Request\x1a).CFamilyGroups_CreateFamilyGroup_Response\x12_\n\x0eGetFamilyGroup\x12%.CFamilyGroups_GetFamilyGroup_Request\x1a&.CFamilyGroups_GetFamilyGroup_Response\x12t\n\x15GetFamilyGroupForUser\x12,.CFamilyGroups_GetFamilyGroupForUser_Request\x1a-.CFamilyGroups_GetFamilyGroupForUser_Response\x12}\n\x18ModifyFamilyGroupDetails\x12/.CFamilyGroups_ModifyFamilyGroupDetails_Request\x1a\x30.CFamilyGroups_ModifyFamilyGroupDetails_Response\x12n\n\x13InviteToFamilyGroup\x12*.CFamilyGroups_InviteToFamilyGroup_Request\x1a+.CFamilyGroups_InviteToFamilyGroup_Response\x12\x83\x01\n\x1a\x43onfirmInviteToFamilyGroup\x12\x31.CFamilyGroups_ConfirmInviteToFamilyGroup_Request\x1a\x32.CFamilyGroups_ConfirmInviteToFamilyGroup_Response\x12\x8c\x01\n\x1dResendInvitationToFamilyGroup\x12\x34.CFamilyGroups_ResendInvitationToFamilyGroup_Request\x1a\x35.CFamilyGroups_ResendInvitationToFamilyGroup_Response\x12\x62\n\x0fJoinFamilyGroup\x12&.CFamilyGroups_JoinFamilyGroup_Request\x1a\'.CFamilyGroups_JoinFamilyGroup_Response\x12w\n\x16\x43onfirmJoinFamilyGroup\x12-.CFamilyGroups_ConfirmJoinFamilyGroup_Request\x1a..CFamilyGroups_ConfirmJoinFamilyGroup_Response\x12t\n\x15RemoveFromFamilyGroup\x12,.CFamilyGroups_RemoveFromFamilyGroup_Request\x1a-.CFamilyGroups_RemoveFromFamilyGroup_Response\x12z\n\x17\x43\x61ncelFamilyGroupInvite\x12..CFamilyGroups_CancelFamilyGroupInvite_Request\x1a/.CFamilyGroups_CancelFamilyGroupInvite_Response\x12t\n\x15GetUsersSharingDevice\x12,.CFamilyGroups_GetUsersSharingDevice_Request\x1a-.CFamilyGroups_GetUsersSharingDevice_Response\x12h\n\x11\x44\x65leteFamilyGroup\x12(.CFamilyGroups_DeleteFamilyGroup_Request\x1a).CFamilyGroups_DeleteFamilyGroup_Response\x12n\n\x13UndeleteFamilyGroup\x12*.CFamilyGroups_UndeleteFamilyGroup_Request\x1a+.CFamilyGroups_UndeleteFamilyGroup_Response\x12k\n\x12GetPlaytimeSummary\x12).CFamilyGroups_GetPlaytimeSummary_Request\x1a*.CFamilyGroups_GetPlaytimeSummary_Response\x12\x62\n\x0fRequestPurchase\x12&.CFamilyGroups_RequestPurchase_Request\x1a\'.CFamilyGroups_RequestPurchase_Response\x12n\n\x13GetPurchaseRequests\x12*.CFamilyGroups_GetPurchaseRequests_Request\x1a+.CFamilyGroups_GetPurchaseRequests_Response\x12\x83\x01\n\x1aRespondToRequestedPurchase\x12\x31.CFamilyGroups_RespondToRequestedPurchase_Request\x1a\x32.CFamilyGroups_RespondToRequestedPurchase_Response\x12Y\n\x0cGetChangeLog\x12#.CFamilyGroups_GetChangeLog_Request\x1a$.CFamilyGroups_GetChangeLog_Response\x12\x83\x01\n\x1aSetFamilyCooldownOverrides\x12\x31.CFamilyGroups_SetFamilyCooldownOverrides_Request\x1a\x32.CFamilyGroups_SetFamilyCooldownOverrides_Response\x12q\n\x14GetSharedLibraryApps\x12+.CFamilyGroups_GetSharedLibraryApps_Request\x1a,.CFamilyGroups_GetSharedLibraryApps_Response\x12k\n\x12SetPreferredLender\x12).CFamilyGroups_SetPreferredLender_Request\x1a*.CFamilyGroups_SetPreferredLender_Response\x12n\n\x13GetPreferredLenders\x12*.CFamilyGroups_GetPreferredLenders_Request\x1a+.CFamilyGroups_GetPreferredLenders_Response\x12h\n\x11\x46orceAcceptInvite\x12(.CFamilyGroups_ForceAcceptInvite_Request\x1a).CFamilyGroups_ForceAcceptInvite_Response\x12t\n\x15GetInviteCheckResults\x12,.CFamilyGroups_GetInviteCheckResults_Request\x1a-.CFamilyGroups_GetInviteCheckResults_Response\x12h\n\x11\x43learCooldownSkip\x12(.CFamilyGroups_ClearCooldownSkip_Request\x1a).CFamilyGroups_ClearCooldownSkip_Response2\x97\x02\n\x12\x46\x61milyGroupsClient\x12U\n\x11NotifyRunningApps\x12\x33.CFamilyGroupsClient_NotifyRunningApps_Notification\x1a\x0b.NoResponse\x12Q\n\x12NotifyInviteStatus\x12..CFamilyGroupsClient_InviteStatus_Notification\x1a\x0b.NoResponse\x12Q\n\x12NotifyGroupChanged\x12..CFamilyGroupsClient_GroupChanged_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_familygroups_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _FAMILYGROUPSCLIENT._options = None
  _FAMILYGROUPSCLIENT._serialized_options = b'\300\265\030\002'
  _EFAMILYGROUPROLE._serialized_start=7446
  _EFAMILYGROUPROLE._serialized_end=7581
  _EFAMILYGROUPSTWOFACTORMETHOD._serialized_start=7584
  _EFAMILYGROUPSTWOFACTORMETHOD._serialized_end=7737
  _EPURCHASEREQUESTACTION._serialized_start=7740
  _EPURCHASEREQUESTACTION._serialized_end=7988
  _EFAMILYGROUPCHANGELOGTYPE._serialized_start=7991
  _EFAMILYGROUPCHANGELOGTYPE._serialized_end=8767
  _ESHAREDLIBRARYEXCLUDEREASON._serialized_start=8770
  _ESHAREDLIBRARYEXCLUDEREASON._serialized_end=10206
  _CFAMILYGROUPS_CREATEFAMILYGROUP_REQUEST._serialized_start=109
  _CFAMILYGROUPS_CREATEFAMILYGROUP_REQUEST._serialized_end=181
  _CFAMILYGROUPS_CREATEFAMILYGROUP_RESPONSE._serialized_start=183
  _CFAMILYGROUPS_CREATEFAMILYGROUP_RESPONSE._serialized_end=280
  _CFAMILYGROUPS_GETFAMILYGROUP_REQUEST._serialized_start=282
  _CFAMILYGROUPS_GETFAMILYGROUP_REQUEST._serialized_end=371
  _FAMILYGROUPMEMBER._serialized_start=374
  _FAMILYGROUPMEMBER._serialized_end=525
  _FAMILYGROUPPENDINGINVITE._serialized_start=527
  _FAMILYGROUPPENDINGINVITE._serialized_end=628
  _FAMILYGROUPFORMERMEMBER._serialized_start=630
  _FAMILYGROUPFORMERMEMBER._serialized_end=672
  _CFAMILYGROUPS_GETFAMILYGROUP_RESPONSE._serialized_start=675
  _CFAMILYGROUPS_GETFAMILYGROUP_RESPONSE._serialized_end=978
  _CFAMILYGROUPS_GETFAMILYGROUPFORUSER_REQUEST._serialized_start=980
  _CFAMILYGROUPS_GETFAMILYGROUPFORUSER_REQUEST._serialized_end=1081
  _FAMILYGROUPPENDINGINVITEFORUSER._serialized_start=1084
  _FAMILYGROUPPENDINGINVITEFORUSER._serialized_end=1246
  _CFAMILYGROUPS_GETFAMILYGROUPFORUSER_RESPONSE._serialized_start=1249
  _CFAMILYGROUPS_GETFAMILYGROUPFORUSER_RESPONSE._serialized_end=1639
  _CFAMILYGROUPS_MODIFYFAMILYGROUPDETAILS_REQUEST._serialized_start=1641
  _CFAMILYGROUPS_MODIFYFAMILYGROUPDETAILS_REQUEST._serialized_end=1727
  _CFAMILYGROUPS_MODIFYFAMILYGROUPDETAILS_RESPONSE._serialized_start=1729
  _CFAMILYGROUPS_MODIFYFAMILYGROUPDETAILS_RESPONSE._serialized_end=1778
  _CFAMILYGROUPS_INVITETOFAMILYGROUP_REQUEST._serialized_start=1781
  _CFAMILYGROUPS_INVITETOFAMILYGROUP_REQUEST._serialized_end=1941
  _CFAMILYGROUPS_INVITETOFAMILYGROUP_RESPONSE._serialized_start=1944
  _CFAMILYGROUPS_INVITETOFAMILYGROUP_RESPONSE._serialized_end=2101
  _CFAMILYGROUPS_CONFIRMINVITETOFAMILYGROUP_REQUEST._serialized_start=2103
  _CFAMILYGROUPS_CONFIRMINVITETOFAMILYGROUP_REQUEST._serialized_end=2211
  _CFAMILYGROUPS_CONFIRMINVITETOFAMILYGROUP_RESPONSE._serialized_start=2213
  _CFAMILYGROUPS_CONFIRMINVITETOFAMILYGROUP_RESPONSE._serialized_end=2264
  _CFAMILYGROUPS_RESENDINVITATIONTOFAMILYGROUP_REQUEST._serialized_start=2266
  _CFAMILYGROUPS_RESENDINVITATIONTOFAMILYGROUP_REQUEST._serialized_end=2360
  _CFAMILYGROUPS_RESENDINVITATIONTOFAMILYGROUP_RESPONSE._serialized_start=2362
  _CFAMILYGROUPS_RESENDINVITATIONTOFAMILYGROUP_RESPONSE._serialized_end=2416
  _CFAMILYGROUPS_JOINFAMILYGROUP_REQUEST._serialized_start=2418
  _CFAMILYGROUPS_JOINFAMILYGROUP_REQUEST._serialized_end=2496
  _CFAMILYGROUPS_JOINFAMILYGROUP_RESPONSE._serialized_start=2499
  _CFAMILYGROUPS_JOINFAMILYGROUP_RESPONSE._serialized_end=2697
  _CFAMILYGROUPS_CONFIRMJOINFAMILYGROUP_REQUEST._serialized_start=2699
  _CFAMILYGROUPS_CONFIRMJOINFAMILYGROUP_REQUEST._serialized_end=2803
  _CFAMILYGROUPS_CONFIRMJOINFAMILYGROUP_RESPONSE._serialized_start=2805
  _CFAMILYGROUPS_CONFIRMJOINFAMILYGROUP_RESPONSE._serialized_end=2852
  _CFAMILYGROUPS_REMOVEFROMFAMILYGROUP_REQUEST._serialized_start=2854
  _CFAMILYGROUPS_REMOVEFROMFAMILYGROUP_REQUEST._serialized_end=2950
  _CFAMILYGROUPS_REMOVEFROMFAMILYGROUP_RESPONSE._serialized_start=2952
  _CFAMILYGROUPS_REMOVEFROMFAMILYGROUP_RESPONSE._serialized_end=2998
  _CFAMILYGROUPS_CANCELFAMILYGROUPINVITE_REQUEST._serialized_start=3000
  _CFAMILYGROUPS_CANCELFAMILYGROUPINVITE_REQUEST._serialized_end=3098
  _CFAMILYGROUPS_CANCELFAMILYGROUPINVITE_RESPONSE._serialized_start=3100
  _CFAMILYGROUPS_CANCELFAMILYGROUPINVITE_RESPONSE._serialized_end=3148
  _CFAMILYGROUPS_GETUSERSSHARINGDEVICE_REQUEST._serialized_start=3150
  _CFAMILYGROUPS_GETUSERSSHARINGDEVICE_REQUEST._serialized_end=3247
  _CFAMILYGROUPS_GETUSERSSHARINGDEVICE_RESPONSE._serialized_start=3249
  _CFAMILYGROUPS_GETUSERSSHARINGDEVICE_RESPONSE._serialized_end=3310
  _CFAMILYGROUPS_DELETEFAMILYGROUP_REQUEST._serialized_start=3312
  _CFAMILYGROUPS_DELETEFAMILYGROUP_REQUEST._serialized_end=3377
  _CFAMILYGROUPS_DELETEFAMILYGROUP_RESPONSE._serialized_start=3379
  _CFAMILYGROUPS_DELETEFAMILYGROUP_RESPONSE._serialized_end=3421
  _CFAMILYGROUPS_UNDELETEFAMILYGROUP_REQUEST._serialized_start=3423
  _CFAMILYGROUPS_UNDELETEFAMILYGROUP_REQUEST._serialized_end=3490
  _CFAMILYGROUPS_UNDELETEFAMILYGROUP_RESPONSE._serialized_start=3492
  _CFAMILYGROUPS_UNDELETEFAMILYGROUP_RESPONSE._serialized_end=3536
  _CFAMILYGROUPS_GETPLAYTIMESUMMARY_REQUEST._serialized_start=3538
  _CFAMILYGROUPS_GETPLAYTIMESUMMARY_REQUEST._serialized_end=3604
  _CFAMILYGROUPS_PLAYTIMEENTRY._serialized_start=3607
  _CFAMILYGROUPS_PLAYTIMEENTRY._serialized_end=3737
  _CFAMILYGROUPS_GETPLAYTIMESUMMARY_RESPONSE._serialized_start=3740
  _CFAMILYGROUPS_GETPLAYTIMESUMMARY_RESPONSE._serialized_end=3886
  _CFAMILYGROUPS_REQUESTPURCHASE_REQUEST._serialized_start=3889
  _CFAMILYGROUPS_REQUESTPURCHASE_REQUEST._serialized_end=4031
  _CFAMILYGROUPS_REQUESTPURCHASE_RESPONSE._serialized_start=4033
  _CFAMILYGROUPS_REQUESTPURCHASE_RESPONSE._serialized_end=4118
  _CFAMILYGROUPS_GETPURCHASEREQUESTS_REQUEST._serialized_start=4120
  _CFAMILYGROUPS_GETPURCHASEREQUESTS_REQUEST._serialized_end=4244
  _PURCHASEREQUEST._serialized_start=4247
  _PURCHASEREQUEST._serialized_end=4632
  _CFAMILYGROUPS_GETPURCHASEREQUESTS_RESPONSE._serialized_start=4634
  _CFAMILYGROUPS_GETPURCHASEREQUESTS_RESPONSE._serialized_end=4714
  _CFAMILYGROUPS_RESPONDTOREQUESTEDPURCHASE_REQUEST._serialized_start=4717
  _CFAMILYGROUPS_RESPONDTOREQUESTEDPURCHASE_REQUEST._serialized_end=4883
  _CFAMILYGROUPS_RESPONDTOREQUESTEDPURCHASE_RESPONSE._serialized_start=4885
  _CFAMILYGROUPS_RESPONDTOREQUESTEDPURCHASE_RESPONSE._serialized_end=4936
  _CFAMILYGROUPS_GETCHANGELOG_REQUEST._serialized_start=4938
  _CFAMILYGROUPS_GETCHANGELOG_REQUEST._serialized_end=4998
  _CFAMILYGROUPS_GETCHANGELOG_RESPONSE._serialized_start=5001
  _CFAMILYGROUPS_GETCHANGELOG_RESPONSE._serialized_end=5250
  _CFAMILYGROUPS_GETCHANGELOG_RESPONSE_CHANGE._serialized_start=5103
  _CFAMILYGROUPS_GETCHANGELOG_RESPONSE_CHANGE._serialized_end=5250
  _CFAMILYGROUPS_SETFAMILYCOOLDOWNOVERRIDES_REQUEST._serialized_start=5252
  _CFAMILYGROUPS_SETFAMILYCOOLDOWNOVERRIDES_REQUEST._serialized_end=5350
  _CFAMILYGROUPS_SETFAMILYCOOLDOWNOVERRIDES_RESPONSE._serialized_start=5352
  _CFAMILYGROUPS_SETFAMILYCOOLDOWNOVERRIDES_RESPONSE._serialized_end=5403
  _CFAMILYGROUPS_GETSHAREDLIBRARYAPPS_REQUEST._serialized_start=5406
  _CFAMILYGROUPS_GETSHAREDLIBRARYAPPS_REQUEST._serialized_end=5601
  _CFAMILYGROUPS_GETSHAREDLIBRARYAPPS_RESPONSE._serialized_start=5604
  _CFAMILYGROUPS_GETSHAREDLIBRARYAPPS_RESPONSE._serialized_end=6106
  _CFAMILYGROUPS_GETSHAREDLIBRARYAPPS_RESPONSE_SHAREDAPP._serialized_start=5745
  _CFAMILYGROUPS_GETSHAREDLIBRARYAPPS_RESPONSE_SHAREDAPP._serialized_end=6106
  _CFAMILYGROUPS_SETPREFERREDLENDER_REQUEST._serialized_start=6108
  _CFAMILYGROUPS_SETPREFERREDLENDER_REQUEST._serialized_end=6213
  _CFAMILYGROUPS_SETPREFERREDLENDER_RESPONSE._serialized_start=6215
  _CFAMILYGROUPS_SETPREFERREDLENDER_RESPONSE._serialized_end=6258
  _CFAMILYGROUPS_GETPREFERREDLENDERS_REQUEST._serialized_start=6260
  _CFAMILYGROUPS_GETPREFERREDLENDERS_REQUEST._serialized_end=6327
  _CFAMILYGROUPS_GETPREFERREDLENDERS_RESPONSE._serialized_start=6330
  _CFAMILYGROUPS_GETPREFERREDLENDERS_RESPONSE._serialized_end=6508
  _CFAMILYGROUPS_GETPREFERREDLENDERS_RESPONSE_FAMILYMEMBER._serialized_start=6451
  _CFAMILYGROUPS_GETPREFERREDLENDERS_RESPONSE_FAMILYMEMBER._serialized_end=6508
  _CFAMILYGROUPS_FORCEACCEPTINVITE_REQUEST._serialized_start=6510
  _CFAMILYGROUPS_FORCEACCEPTINVITE_REQUEST._serialized_end=6592
  _CFAMILYGROUPS_FORCEACCEPTINVITE_RESPONSE._serialized_start=6594
  _CFAMILYGROUPS_FORCEACCEPTINVITE_RESPONSE._serialized_end=6636
  _CFAMILYGROUPS_GETINVITECHECKRESULTS_REQUEST._serialized_start=6638
  _CFAMILYGROUPS_GETINVITECHECKRESULTS_REQUEST._serialized_end=6724
  _CFAMILYGROUPS_GETINVITECHECKRESULTS_RESPONSE._serialized_start=6726
  _CFAMILYGROUPS_GETINVITECHECKRESULTS_RESPONSE._serialized_end=6848
  _CFAMILYGROUPS_CLEARCOOLDOWNSKIP_REQUEST._serialized_start=6850
  _CFAMILYGROUPS_CLEARCOOLDOWNSKIP_REQUEST._serialized_end=6927
  _CFAMILYGROUPS_CLEARCOOLDOWNSKIP_RESPONSE._serialized_start=6929
  _CFAMILYGROUPS_CLEARCOOLDOWNSKIP_RESPONSE._serialized_end=6971
  _CFAMILYGROUPSCLIENT_NOTIFYRUNNINGAPPS_NOTIFICATION._serialized_start=6974
  _CFAMILYGROUPSCLIENT_NOTIFYRUNNINGAPPS_NOTIFICATION._serialized_end=7321
  _CFAMILYGROUPSCLIENT_NOTIFYRUNNINGAPPS_NOTIFICATION_PLAYINGMEMBER._serialized_start=7138
  _CFAMILYGROUPSCLIENT_NOTIFYRUNNINGAPPS_NOTIFICATION_PLAYINGMEMBER._serialized_end=7200
  _CFAMILYGROUPSCLIENT_NOTIFYRUNNINGAPPS_NOTIFICATION_RUNNINGAPP._serialized_start=7202
  _CFAMILYGROUPSCLIENT_NOTIFYRUNNINGAPPS_NOTIFICATION_RUNNINGAPP._serialized_end=7321
  _CFAMILYGROUPSCLIENT_INVITESTATUS_NOTIFICATION._serialized_start=7323
  _CFAMILYGROUPSCLIENT_INVITESTATUS_NOTIFICATION._serialized_end=7370
  _CFAMILYGROUPSCLIENT_GROUPCHANGED_NOTIFICATION._serialized_start=7372
  _CFAMILYGROUPSCLIENT_GROUPCHANGED_NOTIFICATION._serialized_end=7443
  _FAMILYGROUPS._serialized_start=10209
  _FAMILYGROUPS._serialized_end=13205
  _FAMILYGROUPSCLIENT._serialized_start=13208
  _FAMILYGROUPSCLIENT._serialized_end=13487
_builder.BuildServices(DESCRIPTOR, 'steammessages_familygroups_pb2', globals())
# @@protoc_insertion_point(module_scope)



import re
from importlib import import_module

service_lookup = {  # MARK_SERVICE_START
    'AccountHardware':                  'steam.protobufs.steammessages_accounthardware_pb2',
    'Authentication':                   'steam.protobufs.steammessages_auth_pb2',
    'AuthenticationSupport':            'steam.protobufs.steammessages_auth_pb2',
    'CloudGaming':                      'steam.protobufs.steammessages_auth_pb2',
    'Broadcast':                        'steam.protobufs.steammessages_broadcast_pb2',
    'BroadcastClient':                  'steam.protobufs.steammessages_broadcast_pb2',
    'Chat':                             'steam.protobufs.steammessages_chat_pb2',
    'ChatRoom':                         'steam.protobufs.steammessages_chat_pb2',
    'ClanChatRooms':                    'steam.protobufs.steammessages_chat_pb2',
    'ChatRoomClient':                   'steam.protobufs.steammessages_chat_pb2',
    'ChatUsability':                    'steam.protobufs.steammessages_chat_pb2',
    'ChatUsabilityClient':              'steam.protobufs.steammessages_chat_pb2',
    'ClientMetrics':                    'steam.protobufs.steammessages_clientmetrics_pb2',
    'Cloud':                            'steam.protobufs.steammessages_cloud_pb2',
    'CloudClient':                      'steam.protobufs.steammessages_cloud_pb2',
    'Community':                        'steam.protobufs.steammessages_community_pb2',
    'ContentServerDirectory':           'steam.protobufs.steammessages_contentsystem_pb2',
    'DepotContentDetection':            'steam.protobufs.steammessages_contentsystem_pb2',
    'Credentials':                      'steam.protobufs.steammessages_credentials_pb2',
    'DataPublisher':                    'steam.protobufs.steammessages_datapublisher_pb2',
    'ValveHWSurvey':                    'steam.protobufs.steammessages_datapublisher_pb2',
    'ContentBuilder':                   'steam.protobufs.steammessages_depotbuilder_pb2',
    'DeviceAuth':                       'steam.protobufs.steammessages_deviceauth_pb2',
    'Econ':                             'steam.protobufs.steammessages_econ_pb2',
    'FamilyGroups':                     'steam.protobufs.steammessages_familygroups_pb2',
    'FamilyGroupsClient':               'steam.protobufs.steammessages_familygroups_pb2',
    'FriendMessages':                   'steam.protobufs.steammessages_friendmessages_pb2',
    'FriendMessagesClient':             'steam.protobufs.steammessages_friendmessages_pb2',
    'GameNetworking':                   'steam.protobufs.steammessages_gamenetworking_pb2',
    'GameNotifications':                'steam.protobufs.steammessages_gamenotifications_pb2',
    'GameNotificationsClient':          'steam.protobufs.steammessages_gamenotifications_pb2',
    'GameRecordingClip':                'steam.protobufs.steammessages_gamerecording_pb2',
    'VideoClip':                        'steam.protobufs.steammessages_gamerecording_pb2',
    'GameServers':                      'steam.protobufs.steammessages_gameservers_pb2',
    'GameServerClient':                 'steam.protobufs.steammessages_gameservers_pb2',
    'Inventory':                        'steam.protobufs.steammessages_inventory_pb2',
    'InventoryClient':                  'steam.protobufs.steammessages_inventory_pb2',
    'CommunityLinkFilter':              'steam.protobufs.steammessages_linkfilter_pb2',
    'LobbyMatchmakingLegacy':           'steam.protobufs.steammessages_lobbymatchmaking_pb2',
    'MarketingMessages':                'steam.protobufs.steammessages_marketingmessages_pb2',
    'EconMarket':                       'steam.protobufs.steammessages_market_pb2',
    'SteamNotificationClient':          'steam.protobufs.steammessages_notifications_pb2',
    'Offline':                          'steam.protobufs.steammessages_offline_pb2',
    'Parental':                         'steam.protobufs.steammessages_parental_pb2',
    'ParentalClient':                   'steam.protobufs.steammessages_parental_pb2',
    'Parties':                          'steam.protobufs.steammessages_parties_pb2',
    'PartnerApps':                      'steam.protobufs.steammessages_partnerapps_pb2',
    'PhysicalGoods':                    'steam.protobufs.steammessages_physicalgoods_pb2',
    'Player':                           'steam.protobufs.steammessages_player_pb2',
    'PlayerClient':                     'steam.protobufs.steammessages_player_pb2',
    'PublishedFile':                    'steam.protobufs.steammessages_publishedfile_pb2',
    'PublishedFileClient':              'steam.protobufs.steammessages_publishedfile_pb2',
    'QueuedMatchmaking':                'steam.protobufs.steammessages_qms_pb2',
    'QueuedMatchmakingGameHost':        'steam.protobufs.steammessages_qms_pb2',
    'RemoteClient':                     'steam.protobufs.steammessages_remoteclient_service_pb2',
    'RemoteClientSteamClient':          'steam.protobufs.steammessages_remoteclient_service_pb2',
    'Secrets':                          'steam.protobufs.steammessages_secrets_pb2',
    'Shader':                           'steam.protobufs.steammessages_shader_pb2',
    'SiteManagerClient':                'steam.protobufs.steammessages_site_license_pb2',
    'SiteLicense':                      'steam.protobufs.steammessages_site_license_pb2',
    'STAR':                             'steam.protobufs.steammessages_star_pb2',
    'SteamTV':                          'steam.protobufs.steammessages_steamtv_pb2',
    'StoreBrowse':                      'steam.protobufs.steammessages_storebrowse_pb2',
    'Store':                            'steam.protobufs.steammessages_store_pb2',
    'StoreClient':                      'steam.protobufs.steammessages_store_pb2',
    'TimedTrial':                       'steam.protobufs.steammessages_timedtrial_pb2',
    'TwoFactor':                        'steam.protobufs.steammessages_twofactor_pb2',
    'TestSteamClient':                  'steam.protobufs.steammessages_unified_test_pb2',
    'TestServerFromClient':             'steam.protobufs.steammessages_unified_test_pb2',
    'TestExternalPrivilege':            'steam.protobufs.steammessages_unified_test_pb2',
    'UserAccount':                      'steam.protobufs.steammessages_useraccount_pb2',
    'EmbeddedClient':                   'steam.protobufs.steammessages_useraccount_pb2',
    'FileVerification':                 'steam.protobufs.steammessages_vac_pb2',
    'Video':                            'steam.protobufs.steammessages_video_pb2',
    'VideoClient':                      'steam.protobufs.steammessages_video_pb2',
    'FovasVideo':                       'steam.protobufs.steammessages_video_pb2',
    'HelpRequestLogs':                  'steam.protobufs.steammessages_webui_friends_pb2',
    'Community':                        'steam.protobufs.steammessages_webui_friends_pb2',
    'ExperimentService':                'steam.protobufs.steammessages_webui_friends_pb2',
    'FriendsList':                      'steam.protobufs.steammessages_webui_friends_pb2',
    'FriendsListClient':                'steam.protobufs.steammessages_webui_friends_pb2',
    'Clan':                             'steam.protobufs.steammessages_webui_friends_pb2',
    'VoiceChat':                        'steam.protobufs.steammessages_webui_friends_pb2',
    'VoiceChatClient':                  'steam.protobufs.steammessages_webui_friends_pb2',
    'WebRTCClient':                     'steam.protobufs.steammessages_webui_friends_pb2',
    'WebRTCClientNotifications':        'steam.protobufs.steammessages_webui_friends_pb2',
    'MobilePerAccount':                 'steam.protobufs.steammessages_webui_friends_pb2',
    'MobileDevice':                     'steam.protobufs.steammessages_webui_friends_pb2',
    'Workshop':                         'steam.protobufs.steammessages_workshop_pb2',
    'Achievements':                     'steam.protobufs.webuimessages_achievements_pb2',
    'BluetoothManager':                 'steam.protobufs.webuimessages_bluetooth_pb2',
    'GameNotes':                        'steam.protobufs.webuimessages_gamenotes_pb2',
    'GameRecording':                    'steam.protobufs.webuimessages_gamerecording_pb2',
    'Gamescope':                        'steam.protobufs.webuimessages_gamescope_pb2',
    'HardwareUpdate':                   'steam.protobufs.webuimessages_hardwareupdate_pb2',
    'LEDManager':                       'steam.protobufs.webuimessages_leds_pb2',
    'SharedJSContext':                  'steam.protobufs.webuimessages_sharedjscontext_pb2',
    'SteamEngine':                      'steam.protobufs.webuimessages_steamengine_pb2',
    'SteamInputManager':                'steam.protobufs.webuimessages_steaminput_pb2',
    'SteamOSManager':                   'steam.protobufs.webuimessages_steamos_pb2',
    'SteamOSSLS':                       'steam.protobufs.webuimessages_steamos_pb2',
    'StorageDeviceManager':             'steam.protobufs.webuimessages_storagedevicemanager_pb2',
    'SystemManager':                    'steam.protobufs.webuimessages_systemmanager_pb2',
    'TransportAuth':                    'steam.protobufs.webuimessages_transport_pb2',
    'TransportValidation':              'steam.protobufs.webuimessages_transportvalidation_pb2',
    'TransportValidationClient':        'steam.protobufs.webuimessages_transportvalidation_pb2',
}  # MARK_SERVICE_END

method_lookup = {}


def get_um(method_name, response=False):
    """Get protobuf for given method name

    :param method_name: full method name (e.g. ``Player.GetGameBadgeLevels#1``)
    :type method_name: :class:`str`
    :param response: whether to return proto for response or request
    :type response: :class:`bool`
    :return: protobuf message
    """
    key = (method_name, response)

    if key not in method_lookup:
        match = re.findall(r'^([a-z]+)\.([a-z]+)#(\d)?$', method_name, re.I)
        if not match:
            return None

        interface, method, version = match[0]

        if interface not in service_lookup:
            return None

        package = import_module(service_lookup[interface])

        service = getattr(package, interface, None)
        if service is None:
            return None

        for method_desc in service.GetDescriptor().methods:
            name = "%s.%s#%d" % (interface, method_desc.name, 1)

            method_lookup[(name, False)] = getattr(package, method_desc.input_type.full_name, None)
            method_lookup[(name, True)] = getattr(package, method_desc.output_type.full_name, None)

    return method_lookup[key]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_econ.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18steammessages_econ.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xb3\x03\n/CEcon_GetInventoryItemsWithDescriptions_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x11\n\tcontextid\x18\x03 \x01(\x04\x12\x18\n\x10get_descriptions\x18\x04 \x01(\x08\x12\x1c\n\x14get_asset_properties\x18\x0b \x01(\x08\x12$\n\x1c\x66or_trade_offer_verification\x18\n \x01(\x08\x12\x10\n\x08language\x18\x05 \x01(\t\x12O\n\x07\x66ilters\x18\x06 \x01(\x0b\x32>.CEcon_GetInventoryItemsWithDescriptions_Request.FilterOptions\x12\x15\n\rstart_assetid\x18\x08 \x01(\x04\x12\r\n\x05\x63ount\x18\t \x01(\x05\x1a\x66\n\rFilterOptions\x12\x10\n\x08\x61ssetids\x18\x01 \x03(\x04\x12\x13\n\x0b\x63urrencyids\x18\x02 \x03(\r\x12\x15\n\rtradable_only\x18\x03 \x01(\x08\x12\x17\n\x0fmarketable_only\x18\x04 \x01(\x08\"\xab\x01\n\x0b\x43\x45\x63on_Asset\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tcontextid\x18\x02 \x01(\x04\x12\x0f\n\x07\x61ssetid\x18\x03 \x01(\x04\x12\x0f\n\x07\x63lassid\x18\x04 \x01(\x04\x12\x12\n\ninstanceid\x18\x05 \x01(\x04\x12\x12\n\ncurrencyid\x18\x06 \x01(\r\x12\x0e\n\x06\x61mount\x18\x07 \x01(\x03\x12\x0f\n\x07missing\x18\x08 \x01(\x08\x12\x0f\n\x07\x65st_usd\x18\t \x01(\x03\"d\n\x19\x43\x45\x63onItem_DescriptionLine\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05\x63olor\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\".\n\x10\x43\x45\x63onItem_Action\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xf3\x06\n\x15\x43\x45\x63onItem_Description\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x0f\n\x07\x63lassid\x18\x02 \x01(\x04\x12\x12\n\ninstanceid\x18\x03 \x01(\x04\x12\x10\n\x08\x63urrency\x18\x04 \x01(\x08\x12\x18\n\x10\x62\x61\x63kground_color\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x16\n\x0eicon_url_large\x18\x07 \x01(\t\x12\x30\n\x0c\x64\x65scriptions\x18\x08 \x03(\x0b\x32\x1a.CEconItem_DescriptionLine\x12\x10\n\x08tradable\x18\t \x01(\x08\x12\"\n\x07\x61\x63tions\x18\n \x03(\x0b\x32\x11.CEconItem_Action\x12\x36\n\x12owner_descriptions\x18\x0b \x03(\x0b\x32\x1a.CEconItem_DescriptionLine\x12(\n\rowner_actions\x18\x0c \x03(\x0b\x32\x11.CEconItem_Action\x12\x15\n\rfraudwarnings\x18\r \x03(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x12\n\nname_color\x18\x0f \x01(\t\x12\x0c\n\x04type\x18\x10 \x01(\t\x12\x13\n\x0bmarket_name\x18\x11 \x01(\t\x12\x18\n\x10market_hash_name\x18\x12 \x01(\t\x12\x12\n\nmarket_fee\x18\x13 \x01(\t\x12\x16\n\x0emarket_fee_app\x18\x1c \x01(\x05\x12.\n\x0e\x63ontained_item\x18\x14 \x01(\x0b\x32\x16.CEconItem_Description\x12)\n\x0emarket_actions\x18\x15 \x03(\x0b\x32\x11.CEconItem_Action\x12\x11\n\tcommodity\x18\x16 \x01(\x08\x12#\n\x1bmarket_tradable_restriction\x18\x17 \x01(\x05\x12%\n\x1dmarket_marketable_restriction\x18\x18 \x01(\x05\x12\x12\n\nmarketable\x18\x19 \x01(\x08\x12\x1c\n\x04tags\x18\x1a \x03(\x0b\x32\x0e.CEconItem_Tag\x12\x17\n\x0fitem_expiration\x18\x1b \x01(\t\x12&\n\x1emarket_buy_country_restriction\x18\x1e \x01(\t\x12\'\n\x1fmarket_sell_country_restriction\x18\x1f \x01(\t\x12\x0e\n\x06sealed\x18  \x01(\x08\"\x93\x01\n\rCEconItem_Tag\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x15\n\rinternal_name\x18\x03 \x01(\t\x12\x1f\n\x17localized_category_name\x18\x04 \x01(\t\x12\x1a\n\x12localized_tag_name\x18\x05 \x01(\t\x12\r\n\x05\x63olor\x18\x06 \x01(\t\"U\n\x17\x43\x45\x63onItem_AssetProperty\x12\x12\n\npropertyid\x18\x01 \x01(\r\x12\x11\n\tint_value\x18\x02 \x01(\x03\x12\x13\n\x0b\x66loat_value\x18\x03 \x01(\x02\"\x82\x01\n\x19\x43\x45\x63onItem_AssetProperties\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tcontextid\x18\x02 \x01(\x04\x12\x0f\n\x07\x61ssetid\x18\x03 \x01(\x04\x12\x32\n\x10\x61sset_properties\x18\x04 \x03(\x0b\x32\x18.CEconItem_AssetProperty\"\xa3\x02\n0CEcon_GetInventoryItemsWithDescriptions_Response\x12\x1c\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0c.CEcon_Asset\x12,\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32\x16.CEconItem_Description\x12$\n\x0emissing_assets\x18\x03 \x03(\x0b\x32\x0c.CEcon_Asset\x12\x34\n\x10\x61sset_properties\x18\x07 \x03(\x0b\x32\x1a.CEconItem_AssetProperties\x12\x12\n\nmore_items\x18\x04 \x01(\x08\x12\x14\n\x0clast_assetid\x18\x05 \x01(\x04\x12\x1d\n\x15total_inventory_count\x18\x06 \x01(\r\"D\n&CEcon_GetTradeOfferAccessToken_Request\x12\x1a\n\x12generate_new_token\x18\x01 \x01(\x08\"K\n\'CEcon_GetTradeOfferAccessToken_Response\x12 \n\x18trade_offer_access_token\x18\x01 \x01(\t\"C\n-CEcon_ClientGetItemShopOverlayAuthURL_Request\x12\x12\n\nreturn_url\x18\x01 \x01(\t\"=\n.CEcon_ClientGetItemShopOverlayAuthURL_Response\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xbb\x01\n\x1f\x43\x45\x63on_GetAssetClassInfo_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x37\n\x07\x63lasses\x18\x03 \x03(\x0b\x32&.CEcon_GetAssetClassInfo_Request.Class\x12\x10\n\x08high_pri\x18\x04 \x01(\x08\x1a,\n\x05\x43lass\x12\x0f\n\x07\x63lassid\x18\x01 \x01(\x04\x12\x12\n\ninstanceid\x18\x02 \x01(\x04\"P\n CEcon_GetAssetClassInfo_Response\x12,\n\x0c\x64\x65scriptions\x18\x01 \x03(\x0b\x32\x16.CEconItem_Description2\xdf\x03\n\x04\x45\x63on\x12\x88\x01\n!GetInventoryItemsWithDescriptions\x12\x30.CEcon_GetInventoryItemsWithDescriptions_Request\x1a\x31.CEcon_GetInventoryItemsWithDescriptions_Response\x12m\n\x18GetTradeOfferAccessToken\x12\'.CEcon_GetTradeOfferAccessToken_Request\x1a(.CEcon_GetTradeOfferAccessToken_Response\x12\x82\x01\n\x1f\x43lientGetItemShopOverlayAuthURL\x12..CEcon_ClientGetItemShopOverlayAuthURL_Request\x1a/.CEcon_ClientGetItemShopOverlayAuthURL_Response\x12X\n\x11GetAssetClassInfo\x12 .CEcon_GetAssetClassInfo_Request\x1a!.CEcon_GetAssetClassInfo_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_econ_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST._serialized_start=89
  _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST._serialized_end=524
  _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST_FILTEROPTIONS._serialized_start=422
  _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_REQUEST_FILTEROPTIONS._serialized_end=524
  _CECON_ASSET._serialized_start=527
  _CECON_ASSET._serialized_end=698
  _CECONITEM_DESCRIPTIONLINE._serialized_start=700
  _CECONITEM_DESCRIPTIONLINE._serialized_end=800
  _CECONITEM_ACTION._serialized_start=802
  _CECONITEM_ACTION._serialized_end=848
  _CECONITEM_DESCRIPTION._serialized_start=851
  _CECONITEM_DESCRIPTION._serialized_end=1734
  _CECONITEM_TAG._serialized_start=1737
  _CECONITEM_TAG._serialized_end=1884
  _CECONITEM_ASSETPROPERTY._serialized_start=1886
  _CECONITEM_ASSETPROPERTY._serialized_end=1971
  _CECONITEM_ASSETPROPERTIES._serialized_start=1974
  _CECONITEM_ASSETPROPERTIES._serialized_end=2104
  _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE._serialized_start=2107
  _CECON_GETINVENTORYITEMSWITHDESCRIPTIONS_RESPONSE._serialized_end=2398
  _CECON_GETTRADEOFFERACCESSTOKEN_REQUEST._serialized_start=2400
  _CECON_GETTRADEOFFERACCESSTOKEN_REQUEST._serialized_end=2468
  _CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE._serialized_start=2470
  _CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE._serialized_end=2545
  _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST._serialized_start=2547
  _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST._serialized_end=2614
  _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE._serialized_start=2616
  _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE._serialized_end=2677
  _CECON_GETASSETCLASSINFO_REQUEST._serialized_start=2680
  _CECON_GETASSETCLASSINFO_REQUEST._serialized_end=2867
  _CECON_GETASSETCLASSINFO_REQUEST_CLASS._serialized_start=2823
  _CECON_GETASSETCLASSINFO_REQUEST_CLASS._serialized_end=2867
  _CECON_GETASSETCLASSINFO_RESPONSE._serialized_start=2869
  _CECON_GETASSETCLASSINFO_RESPONSE._serialized_end=2949
  _ECON._serialized_start=2952
  _ECON._serialized_end=3431
_builder.BuildServices(DESCRIPTOR, 'steammessages_econ_pb2', globals())
# @@protoc_insertion_point(module_scope)



from weakref import WeakValueDictionary
from steam.client.user import SteamUser
from steam.enums import EPersonaState, EChatEntryType, EType, EClientUIMode
from steam.enums.emsg import EMsg
from steam.core.msg import MsgProto
from steam.utils.proto import proto_fill_from_dict

class User(object):
    EVENT_CHAT_MESSAGE = 'chat_message'
    """On new private chat message

    :param user: steam user
    :type user: :class:`.SteamUser`
    :param message: message text
    :type message: str
    """

    persona_state = EPersonaState.Online    #: current persona state
    user = None                             #: :class:`.SteamUser` instance once logged on
    current_games_played = []               #: :class:`list` of app ids currently being played

    def __init__(self, *args, **kwargs):
        super(User, self).__init__(*args, **kwargs)

        self._user_cache = WeakValueDictionary()

        self.on(self.EVENT_DISCONNECTED, self.__handle_disconnect)
        self.on(self.EVENT_LOGGED_ON, self.__handle_set_persona)
        self.on(EMsg.ClientPersonaState, self.__handle_persona_state)
        self.on(EMsg.ClientFriendMsgIncoming, self.__handle_message_incoming)
        self.on("FriendMessagesClient.IncomingMessage#1", self.__handle_message_incoming2)

    def __handle_message_incoming(self, msg):
        # old chat
        if msg.body.chat_entry_type == EChatEntryType.ChatMsg:
            user = self.get_user(msg.body.steamid_from)
            self.emit("chat_message", user, msg.body.message.decode('utf-8'))

    def __handle_message_incoming2(self, msg):
        # new chat
        if msg.body.chat_entry_type == EChatEntryType.ChatMsg and not msg.body.local_echo:
            user = self.get_user(msg.body.steamid_friend)
            self.emit("chat_message", user, msg.body.message)

    def __handle_disconnect(self):
        self.user = None
        self.current_games_played = []

    def __handle_set_persona(self):
        self.user = self.get_user(self.steam_id, False)

        if self.steam_id.type == EType.Individual and self.persona_state != EPersonaState.Offline:
            self.change_status(persona_state=self.persona_state)

    def __handle_persona_state(self, message):
        for friend in message.body.friends:
            steamid = friend.friendid

            if steamid in self._user_cache:
                suser = self._user_cache[steamid]
                suser._pstate = friend
                suser._pstate_ready.set()

    def change_status(self, **kwargs):
        """
        Set name, persona state, flags

        .. note::
            Changing persona state will also change :attr:`persona_state`

        :param persona_state: persona state (Online/Offline/Away/etc)
        :type persona_state: :class:`.EPersonaState`
        :param player_name: profile name
        :type player_name: :class:`str`
        :param persona_state_flags: persona state flags
        :type persona_state_flags: :class:`.EPersonaStateFlag`
        """
        if not kwargs: return

        self.persona_state = kwargs.get('persona_state', self.persona_state)

        message = MsgProto(EMsg.ClientChangeStatus)
        proto_fill_from_dict(message.body, kwargs)
        self.send(message)

    def request_persona_state(self, steam_ids, state_flags=863):
        """Request persona state data

        :param steam_ids: list of steam ids
        :type  steam_ids: :class:`list`
        :param state_flags: client state flags
        :type  state_flags: :class:`.EClientPersonaStateFlag`
        """
        m = MsgProto(EMsg.ClientRequestFriendData)
        m.body.persona_state_requested = state_flags
        m.body.friends.extend(steam_ids)
        self.send(m)

    def get_user(self, steam_id, fetch_persona_state=True):
        """Get :class:`.SteamUser` instance for ``steam id``

        :param steam_id: steam id
        :type steam_id: :class:`int`, :class:`.SteamID`
        :param fetch_persona_state: whether to request person state when necessary
        :type fetch_persona_state: :class:`bool`
        :return: SteamUser instance
        :rtype: :class:`.SteamUser`
        """
        steam_id = int(steam_id)
        suser = self._user_cache.get(steam_id, None)

        if suser is None:
            suser = SteamUser(steam_id, self)
            self._user_cache[steam_id] = suser

            if fetch_persona_state:
                suser.refresh(wait=False)

        return suser

    def games_played(self, app_ids):
        """
        Set the apps being played by the user

        :param app_ids: a list of application ids
        :type app_ids: :class:`list`

        These app ids will be recorded in :attr:`current_games_played`.
        """
        if not isinstance(app_ids, list):
            raise ValueError("Expected app_ids to be of type list")

        self.current_games_played = app_ids = list(map(int, app_ids))

        self.send(MsgProto(EMsg.ClientGamesPlayed),
                  {'games_played': [{'game_id': app_id} for app_id in app_ids]}
                  )

    def set_ui_mode(self, uimode):
        """
        Set UI mode. Show little icon next to name in friend list. (e.g phone, controller, other)

        :param uimode: UI mode integer
        :type  uimode: :class:`EClientUIMode`

        These app ids will be recorded in :attr:`current_games_played`.
        """
        self.send(MsgProto(EMsg.ClientCurrentUIMode), {'uimode': EClientUIMode(uimode)})



"""Classes to (de)serialize message headers"""
import struct
from steam.enums.emsg import EMsg
from steam.protobufs import steammessages_base_pb2
from steam.protobufs import gc_pb2
from steam.utils.proto import set_proto_bit, clear_proto_bit


class MsgHdr:
    _size = struct.calcsize("<Iqq")
    msg = EMsg.Invalid
    targetJobID = -1
    sourceJobID = -1

    def __init__(self, data=None):
        if data: self.load(data)

    def serialize(self):
        return struct.pack("<Iqq", self.msg, self.targetJobID, self.sourceJobID)

    def load(self, data):
        (msg, self.targetJobID, self.sourceJobID) = struct.unpack_from("<Iqq", data)
        self.msg = EMsg(msg)

    def __str__(self):
        return '\n'.join(["msg: %s" % repr(self.msg),
                          "targetJobID: %s" % self.targetJobID,
                          "sourceJobID: %s" % self.sourceJobID,
                          ])

class ExtendedMsgHdr:
    _size = struct.calcsize("<IBHqqBqi")
    msg = EMsg.Invalid
    headerSize = 36
    headerVersion = 2
    targetJobID = -1
    sourceJobID = -1
    headerCanary = 239
    steamID = -1
    sessionID = -1

    def __init__(self, data=None):
        if data: self.load(data)

    def serialize(self):
        return struct.pack("<IBHqqBqi",
                           self.msg,
                           self.headerSize,
                           self.headerVersion,
                           self.targetJobID,
                           self.sourceJobID,
                           self.headerCanary,
                           self.steamID,
                           self.sessionID,
                           )

    def load(self, data):
        (msg,
         self.headerSize,
         self.headerVersion,
         self.targetJobID,
         self.sourceJobID,
         self.headerCanary,
         self.steamID,
         self.sessionID,
         ) = struct.unpack_from("<IBHqqBqi", data)

        self.msg = EMsg(msg)

        if self.headerSize != 36 or self.headerVersion != 2:
            raise RuntimeError("Failed to parse header")

    def __str__(self):
        return '\n'.join(["msg: %s" % self.msg,
                          "headerSize: %s" % self.headerSize,
                          "headerVersion: %s" % self.headerVersion,
                          "targetJobID: %s" % self.targetJobID,
                          "sourceJobID: %s" % self.sourceJobID,
                          "headerCanary: %s" % self.headerCanary,
                          "steamID: %s" % self.steamID,
                          "sessionID: %s" % self.sessionID,
                          ])


class MsgHdrProtoBuf:
    _size = _fullsize = struct.calcsize("<II")
    msg = EMsg.Invalid

    def __init__(self, data=None):
        self.proto = steammessages_base_pb2.CMsgProtoBufHeader()

        if data:
            self.load(data)

    def serialize(self):
        proto_data = self.proto.SerializeToString()
        return struct.pack("<II", set_proto_bit(self.msg), len(proto_data)) + proto_data

    def load(self, data):
        msg, proto_length = struct.unpack_from("<II", data)

        self.msg = EMsg(clear_proto_bit(msg))
        size = MsgHdrProtoBuf._size
        self._fullsize = size + proto_length
        self.proto.ParseFromString(data[size:self._fullsize])


class GCMsgHdr:
    _size = struct.calcsize("<Hqq")
    proto = None
    headerVersion = 1
    targetJobID = -1
    sourceJobID = -1

    def __init__(self, msg, data=None):
        self.msg = clear_proto_bit(msg)

        if data:
            self.load(data)

    def serialize(self):
        return struct.pack("<Hqq",
                           self.headerVersion,
                           self.targetJobID,
                           self.sourceJobID,
                           )

    def load(self, data):
        (self.headerVersion,
         self.targetJobID,
         self.sourceJobID,
         ) = struct.unpack_from("<Hqq", data)

    def __str__(self):
        return '\n'.join(["headerVersion: %s" % self.headerVersion,
                          "targetJobID: %s" % self.targetJobID,
                          "sourceJobID: %s" % self.sourceJobID,
                          ])

class GCMsgHdrProto:
    _size = struct.calcsize("<Ii")
    headerLength = 0

    def __init__(self, msg, data=None):
        self.proto = gc_pb2.CMsgProtoBufHeader()
        self.msg = clear_proto_bit(msg)

        if data:
            self.load(data)

    def serialize(self):
        proto_data = self.proto.SerializeToString()
        self.headerLength = len(proto_data)

        return struct.pack("<Ii",
                           set_proto_bit(self.msg),
                           self.headerLength,
                           ) + proto_data

    def load(self, data):
        (msg,
         self.headerLength,
         ) = struct.unpack_from("<Ii", data)

        self.msg = clear_proto_bit(msg)

        if self.headerLength:
            x = GCMsgHdrProto._size
            self.proto.ParseFromString(data[x:x+self.headerLength])

    def __str__(self):
        resp = ["msg: %s" % self.msg,
                "headerLength: %s" % self.headerLength,
                ]

        proto = str(self.proto)

        if proto:
            resp.append('-- proto --')
            resp.append(proto)

        return '\n'.join(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_gamerecording.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2
import steam.protobufs.webuimessages_gamerecordingfiles_pb2 as webuimessages__gamerecordingfiles__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!webuimessages_gamerecording.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\x1a&webuimessages_gamerecordingfiles.proto\"3\n1CGameRecording_GetAppsWithBackgroundVideo_Request\"\xe8\x02\n2CGameRecording_GetAppsWithBackgroundVideo_Response\x12\x45\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x37.CGameRecording_GetAppsWithBackgroundVideo_Response.App\x1a\xea\x01\n\x03\x41pp\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x1e\n\x16most_recent_start_time\x18\x02 \x01(\r\x12I\n\x0erecording_type\x18\x03 \x01(\x0e\x32\x13.EGameRecordingType:\x1ck_EGameRecordingType_Unknown\x12\x1e\n\x16video_duration_seconds\x18\x04 \x01(\x01\x12!\n\x19timeline_duration_seconds\x18\x05 \x01(\x01\x12\x11\n\tis_active\x18\x06 \x01(\x08\x12\x11\n\tfile_size\x18\x07 \x01(\x04\"<\n)CGameRecording_GetTimelinesForApp_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\"`\n*CGameRecording_GetTimelinesForApp_Response\x12\x32\n\ttimelines\x18\x01 \x03(\x0b\x32\x1f.CGameRecordingTimelineMetadata\"=\n*CGameRecording_GetTimelinesForClip_Request\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\"\x9a\x01\n+CGameRecording_GetTimelinesForClip_Response\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x32\n\ttimelines\x18\x02 \x03(\x0b\x32\x1f.CGameRecordingTimelineMetadata\x12&\n\x1e\x66irst_timeline_start_offset_ms\x18\x03 \x01(\x04\"\xf1\x01\n\"CGameRecording_QueryPhases_Request\x12\x0c\n\x04page\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x15\n\rfilter_gameid\x18\n \x01(\x04\x12\x1c\n\x14\x66ilter_search_string\x18\x0b \x01(\t\x12<\n\x0b\x66ilter_tags\x18\x0c \x03(\x0b\x32\'.CGameRecording_QueryPhases_Request.Tag\x12\x17\n\x0f\x66ilter_phase_id\x18\r \x01(\t\x1a\"\n\x03Tag\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9d\x05\n#CGameRecording_QueryPhases_Response\x12:\n\x06phases\x18\x01 \x03(\x0b\x32*.CGameRecording_QueryPhases_Response.Phase\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x1a\xa4\x04\n\x05Phase\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x15\n\rdate_recorded\x18\x05 \x01(\r\x12\x13\n\x0b\x64uration_ms\x18\x06 \x01(\x04\x12\x1b\n\x04tags\x18\x07 \x03(\x0b\x32\r.CTimelineTag\x12%\n\x0e\x63ontained_tags\x18\x08 \x03(\x0b\x32\r.CTimelineTag\x12\\\n\x14\x62\x61\x63kground_recording\x18\t \x01(\x0b\x32>.CGameRecording_QueryPhases_Response.Phase.BackgroundRecording\x12\x10\n\x08\x63lip_ids\x18\n \x03(\t\x12=\n\x04type\x18\x0b \x01(\x0e\x32\x11.EPhaseResultType:\x1ck_EPhaseResultType_Automatic\x12\x10\n\x08start_ms\x18\x0c \x01(\x04\x12\x13\n\x0bscreenshots\x18\r \x03(\r\x12\x0e\n\x06\x61\x63tive\x18\x0e \x01(\x08\x12\x10\n\x08phase_id\x18\x0f \x01(\t\x12+\n\x12significant_events\x18\x10 \x03(\x0b\x32\x0f.CTimelineEntry\x12$\n\nattributes\x18\x11 \x03(\x0b\x32\x10.CPhaseAttribute\x1aO\n\x13\x42\x61\x63kgroundRecording\x12\x13\n\x0btimeline_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\x13\n\x0b\x64uration_ms\x18\x03 \x01(\x04\"1\n\x1e\x43GameRecording_GetTags_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\">\n\x1f\x43GameRecording_GetTags_Response\x12\x1b\n\x04tags\x18\x01 \x03(\x0b\x32\r.CTimelineTag\"+\n)CGameRecording_GetEnoughDiskSpace_Request\"B\n*CGameRecording_GetEnoughDiskSpace_Response\x12\x14\n\x0c\x65nough_space\x18\x01 \x01(\x08\".\n,CGameRecording_GetAvailableDiskSpace_Request\"=\n-CGameRecording_GetAvailableDiskSpace_Response\x12\x0c\n\x04size\x18\x01 \x01(\x01\"\xe4\x01\n+CGameRecording_TimelineChanged_Notification\x12\x66\n\x11notification_type\x18\x01 \x01(\x0e\x32 .ETimelineChangeNotificationType:)k_ETimelineChangeNotificationType_Started\x12\x13\n\x0btimeline_id\x18\x02 \x01(\t\x12\x0f\n\x07game_id\x18\x03 \x01(\x04\x12\x12\n\nstart_time\x18\x04 \x01(\r\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\x04\"\xdd\x02\n3CGameRecording_RecordingSessionChanged_Notification\x12v\n\x11notification_type\x18\x01 \x01(\x0e\x32(.ERecordingSessionChangeNotificationType:1k_ERecordingSessionChangeNotificationType_Started\x12\x13\n\x0btimeline_id\x18\x02 \x01(\t\x12\x0f\n\x07game_id\x18\x04 \x01(\x04\x12\x12\n\nsession_id\x18\x05 \x01(\t\x12\x14\n\x0cstart_offset\x18\x06 \x01(\x04\x12\x13\n\x0b\x64uration_ms\x18\x07 \x01(\x04\x12I\n\x0erecording_type\x18\x08 \x01(\x0e\x32\x13.EGameRecordingType:\x1ck_EGameRecordingType_Unknown\"\xcf\x03\n\x0e\x43TimelineEntry\x12\x13\n\x0btimeline_id\x18\x01 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x02 \x01(\x04\x12\x0c\n\x04time\x18\x03 \x01(\x04\x12?\n\x04type\x18\x04 \x01(\x0e\x32\x13.ETimelineEntryType:\x1ck_ETimelineEntryType_Invalid\x12\x11\n\tgame_mode\x18\x05 \x01(\x05\x12\x13\n\x0brange_title\x18\x07 \x01(\t\x12\x16\n\x0erange_duration\x18\x08 \x01(\x04\x12\x1b\n\x13range_possible_clip\x18\t \x01(\x05\x12\x17\n\x0ftimestamp_title\x18\n \x01(\t\x12\x13\n\x0bmarker_icon\x18\x0b \x01(\t\x12\x1a\n\x12marker_description\x18\r \x01(\t\x12\x17\n\x0fmarker_priority\x18\x0e \x01(\x05\x12\x19\n\x11screenshot_handle\x18\x0f \x01(\r\x12\x18\n\x10\x61\x63hievement_name\x18\x10 \x01(\t\x12\x1a\n\x03tag\x18\x11 \x03(\x0b\x32\r.CTimelineTag\x12\x10\n\x08phase_id\x18\x12 \x01(\t\x12$\n\nattributes\x18\x13 \x03(\x0b\x32\x10.CPhaseAttribute\"c\n0CGameRecording_TimelineEntryChanged_Notification\x12\x1e\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x0f.CTimelineEntry\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\"j\n0CGameRecording_TimelineEntryRemoved_Notification\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x13\n\x0btimeline_id\x18\x02 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x03 \x01(\x04\"*\n(CGameRecording_LowDiskSpace_Notification\"H\n5CGameRecording_PostGameHighlightsChanged_Notification\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\"W\n2CGameRecording_OpenOverlayToGamePhase_Notification\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x10\n\x08phase_id\x18\x02 \x01(\t\"[\n6CGameRecording_OpenOverlayToTimelineEvent_Notification\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x10\n\x08\x65ntry_id\x18\x02 \x01(\x04\".\n,CGameRecording_PhaseListChanged_Notification\"\xa4\x03\n\x1a\x43GameRecording_ClipSummary\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\x12\x0f\n\x07game_id\x18\x02 \x01(\x04\x12\x13\n\x0b\x64uration_ms\x18\x03 \x01(\x04\x12\x15\n\rdate_recorded\x18\x04 \x01(\r\x12\x19\n\x11start_timeline_id\x18\x05 \x01(\t\x12\x17\n\x0fstart_offset_ms\x18\x06 \x01(\x04\x12\x19\n\x11published_file_id\x18\x07 \x01(\x04\x12\x11\n\tfile_size\x18\x08 \x01(\x04\x12\x0c\n\x04name\x18\t \x01(\t\x12\x14\n\x0c\x64\x61te_clipped\x18\n \x01(\r\x12\x11\n\ttemporary\x18\x0b \x01(\x08\x12\x17\n\x0foriginal_device\x18\x0c \x01(\t\x12#\n\x1boriginal_gaming_device_type\x18\r \x01(\r\x12\x17\n\x0f\x64\x61te_downloaded\x18\x0e \x01(\r\x12\x15\n\rthumbnail_url\x18\x0f \x01(\t\x12\x17\n\x0fthumbnail_width\x18\x10 \x01(\r\x12\x18\n\x10thumbnail_height\x18\x11 \x01(\r\"\xa7\x02\n\x1f\x43GameRecording_SaveClip_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x38\n\x05start\x18\x02 \x01(\x0b\x32).CGameRecording_SaveClip_Request.Position\x12\x36\n\x03\x65nd\x18\x03 \x01(\x0b\x32).CGameRecording_SaveClip_Request.Position\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0bsrc_clip_id\x18\x05 \x01(\t\x12\x11\n\ttemporary\x18\x06 \x01(\x08\x12\x17\n\x0f\x66orce_thumbnail\x18\x07 \x01(\x08\x1a\x32\n\x08Position\x12\x13\n\x0btimeline_id\x18\x01 \x01(\t\x12\x11\n\toffset_ms\x18\x02 \x01(\x04\"P\n CGameRecording_SaveClip_Response\x12,\n\x07summary\x18\x01 \x01(\x0b\x32\x1b.CGameRecording_ClipSummary\"4\n!CGameRecording_DeleteClip_Request\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\"$\n\"CGameRecording_DeleteClip_Response\"\xaa\x01\n\"CGameRecording_ExportClip_Settings\x12\x14\n\x0c\x62itrate_kbps\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x19\n\x11\x66rames_per_second\x18\x04 \x01(\x05\x12\x34\n\x05\x63odec\x18\x05 \x01(\x0e\x32\r.EExportCodec:\x16k_EExportCodec_Default\"\xa1\x01\n!CGameRecording_ExportClip_Request\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\x12\x17\n\x0f\x65xport_mp4_path\x18\x02 \x01(\t\x12\x35\n\x08settings\x18\x03 \x01(\x0b\x32#.CGameRecording_ExportClip_Settings\x12\x1b\n\x13use_unique_filename\x18\x04 \x01(\x08\"$\n\"CGameRecording_ExportClip_Response\"\x8d\x01\n(CGameRecording_ExportClipPreview_Request\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\x12\x35\n\x08settings\x18\x02 \x01(\x0b\x32#.CGameRecording_ExportClip_Settings\x12\x19\n\x11run_policy_checks\x18\x03 \x01(\x08\"z\n)CGameRecording_ExportClipPreview_Response\x12\x16\n\x0e\x65stimated_size\x18\x01 \x01(\x04\x12\x35\n\x08settings\x18\x02 \x01(\x0b\x32#.CGameRecording_ExportClip_Settings\"i\n%CGameRecording_TakeScreenshot_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x13\n\x0btimeline_id\x18\x02 \x01(\t\x12\x1a\n\x12timeline_offset_ms\x18\x03 \x01(\x04\"?\n&CGameRecording_TakeScreenshot_Response\x12\x15\n\rscreenshot_id\x18\x01 \x01(\x06\"l\n(CGameRecording_UploadClipToSteam_Request\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x12\n\nvisibility\x18\x04 \x01(\x05\"Y\n)CGameRecording_UploadClipToSteam_Response\x12,\n\x07summary\x18\x01 \x01(\x0b\x32\x1b.CGameRecording_ClipSummary\"1\n\x1e\x43GameRecording_ZipClip_Request\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\"3\n\x1f\x43GameRecording_ZipClip_Response\x12\x10\n\x08zip_path\x18\x01 \x01(\t\"d\n\x1f\x43GameRecording_GetClips_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x15\n\rcreated_after\x18\x02 \x01(\r\x12\x19\n\x11include_temporary\x18\x03 \x01(\x08\"M\n CGameRecording_GetClips_Response\x12)\n\x04\x63lip\x18\x01 \x03(\x0b\x32\x1b.CGameRecording_ClipSummary\"]\n3CGameRecording_GetAndTrimPostGameHighlights_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x15\n\rcreated_after\x18\x02 \x01(\r\"d\n4CGameRecording_GetAndTrimPostGameHighlights_Response\x12,\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1c.CGameRecordingTimelineEvent\"o\n+CGameRecording_UserAddTimelineEntry_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x1e\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\x0f.CTimelineEntry\x12\x0f\n\x07\x63lip_id\x18\x03 \x01(\t\"@\n,CGameRecording_UserAddTimelineEntry_Response\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\x04\"r\n.CGameRecording_UserUpdateTimelineEntry_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x1e\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\x0f.CTimelineEntry\x12\x0f\n\x07\x63lip_id\x18\x03 \x01(\t\"1\n/CGameRecording_UserUpdateTimelineEntry_Response\"y\n.CGameRecording_UserRemoveTimelineEntry_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x13\n\x0btimeline_id\x18\x02 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x03 \x01(\x04\x12\x0f\n\x07\x63lip_id\x18\x04 \x01(\t\"1\n/CGameRecording_UserRemoveTimelineEntry_Response\"J\n6CGameRecording_ManuallyDeleteRecordingsForApps_Request\x12\x10\n\x08game_ids\x18\x01 \x03(\x04\"9\n7CGameRecording_ManuallyDeleteRecordingsForApps_Response\"\x7f\n-CGameRecording_GetTotalDiskSpaceUsage_Request\x12\x13\n\x0b\x66older_path\x18\x01 \x01(\t\x12\x39\n\x04type\x18\x02 \x01(\x0e\x32\x0f.EDiskSpaceType:\x1ak_eDiskSpaceType_Recording\">\n.CGameRecording_GetTotalDiskSpaceUsage_Response\x12\x0c\n\x04size\x18\x01 \x01(\x04\"\xfe\x01\n$CGameRecording_GetThumbnails_Request\x12\x14\n\x0crecording_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63lip_id\x18\x03 \x01(\t\x12\x13\n\x0btimeline_id\x18\x07 \x01(\t\x12\x17\n\x0fstart_offset_us\x18\x04 \x03(\x03\x12\x17\n\nmajor_axis\x18\x05 \x01(\r:\x03\x35\x31\x32\x12<\n\x0etime_precision\x18\x06 \x01(\x0e\x32\x18.EThumbnailTimePrecision:\nk_ePrecise\x12*\n\x06\x66ormat\x18\x08 \x01(\x0e\x32\x11.EThumbnailFormat:\x07k_eJPEG\"\xad\x01\n%CGameRecording_GetThumbnails_Response\x12\x44\n\nthumbnails\x18\x01 \x03(\x0b\x32\x30.CGameRecording_GetThumbnails_Response.Thumbnail\x1a>\n\tThumbnail\x12\x12\n\nimage_data\x18\x01 \x01(\x0c\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\"8\n%CGameRecording_StartRecording_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\"(\n&CGameRecording_StartRecording_Response\"7\n$CGameRecording_StopRecording_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\"U\n%CGameRecording_StopRecording_Response\x12,\n\x07summary\x18\x01 \x01(\x0b\x32\x1b.CGameRecording_ClipSummary\":\n\'CGameRecording_GetRecordingSize_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\"=\n(CGameRecording_GetRecordingSize_Response\x12\x11\n\tfile_size\x18\x01 \x01(\x04\"4\n2CGameRecording_CleanupBackgroundRecordings_Request\"5\n3CGameRecording_CleanupBackgroundRecordings_Response\"0\n.CGameRecording_GetPlatformCapabilities_Request\"T\n/CGameRecording_GetPlatformCapabilities_Response\x12!\n\x19per_process_audio_capture\x18\x01 \x01(\x08\"W\n\'CGameRecording_ClipCreated_Notification\x12,\n\x07summary\x18\x01 \x01(\x0b\x32\x1b.CGameRecording_ClipSummary\"K\n\'CGameRecording_ClipDeleted_Notification\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\x12\x0f\n\x07game_id\x18\x02 \x01(\x04\"`\n*CGameRecording_ExportProgress_Notification\x12\x10\n\x08progress\x18\x01 \x01(\x02\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65result\x18\x03 \x01(\x05\"u\n\x1e\x43GameRecording_PerGameSettings\x12\x0e\n\x06gameid\x18\x01 \x01(\x06\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x0f\n\x07minutes\x18\x03 \x01(\r\x12\x0f\n\x07\x62itrate\x18\x04 \x01(\t\x12\x10\n\x08infinite\x18\x05 \x01(\x08\"+\n)CGameRecording_GetPerGameSettings_Request\"_\n*CGameRecording_GetPerGameSettings_Response\x12\x31\n\x08settings\x18\x01 \x03(\x0b\x32\x1f.CGameRecording_PerGameSettings\"c\n)CGameRecording_SetPerGameSettings_Request\x12\x36\n\rgame_settings\x18\x01 \x01(\x0b\x32\x1f.CGameRecording_PerGameSettings\",\n*CGameRecording_SetPerGameSettings_Response\">\n,CGameRecording_DeletePerGameSettings_Request\x12\x0e\n\x06gameid\x18\x01 \x01(\x06\"/\n-CGameRecording_DeletePerGameSettings_Response\"`\n*CGameRecording_UploadProgress_Notification\x12\x10\n\x08progress\x18\x01 \x01(\x02\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65result\x18\x03 \x01(\x05\"G\n4CGameRecording_SwitchBackgroundRecordingGame_Request\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\"7\n5CGameRecording_SwitchBackgroundRecordingGame_Response*\xf6\x02\n\x12\x45TimelineEntryType\x12 \n\x1ck_ETimelineEntryType_Invalid\x10\x00\x12!\n\x1dk_ETimelineEntryType_GameMode\x10\x01\x12\x1e\n\x1ak_ETimelineEntryType_Event\x10\x02\x12)\n%k_ETimelineEntryType_StateDescription\x10\x03\x12$\n k_ETimelineEntryType_Achievement\x10\x04\x12#\n\x1fk_ETimelineEntryType_UserMarker\x10\x05\x12#\n\x1fk_ETimelineEntryType_Screenshot\x10\x06\x12\x1e\n\x1ak_ETimelineEntryType_Error\x10\x07\x12\x1c\n\x18k_ETimelineEntryType_Tag\x10\x08\x12\"\n\x1ek_ETimelineEntryType_GamePhase\x10\t*n\n\x10\x45PhaseResultType\x12 \n\x1ck_EPhaseResultType_Automatic\x10\x01\x12\x1c\n\x18k_EPhaseResultType_Blank\x10\x02\x12\x1a\n\x16k_EPhaseResultType_API\x10\x03*\xd6\x02\n\x1f\x45TimelineChangeNotificationType\x12-\n)k_ETimelineChangeNotificationType_Started\x10\x01\x12-\n)k_ETimelineChangeNotificationType_Stopped\x10\x02\x12-\n)k_ETimelineChangeNotificationType_Deleted\x10\x03\x12\x36\n2k_ETimelineChangeNotificationType_RecordingStarted\x10\x04\x12\x36\n2k_ETimelineChangeNotificationType_RecordingStopped\x10\x05\x12\x36\n2k_ETimelineChangeNotificationType_RecordingUpdated\x10\x06*\x85\x02\n\'ERecordingSessionChangeNotificationType\x12\x35\n1k_ERecordingSessionChangeNotificationType_Started\x10\x01\x12\x35\n1k_ERecordingSessionChangeNotificationType_Stopped\x10\x02\x12\x35\n1k_ERecordingSessionChangeNotificationType_Deleted\x10\x03\x12\x35\n1k_ERecordingSessionChangeNotificationType_Updated\x10\x04*K\n\x0e\x45\x44iskSpaceType\x12\x1e\n\x1ak_eDiskSpaceType_Recording\x10\x00\x12\x19\n\x15k_eDiskSpaceType_Clip\x10\x01*7\n\x17\x45ThumbnailTimePrecision\x12\x0e\n\nk_ePrecise\x10\x00\x12\x0c\n\x08k_eLoose\x10\x01*+\n\x10\x45ThumbnailFormat\x12\x0b\n\x07k_eJPEG\x10\x01\x12\n\n\x06k_eRGB\x10\x02\x32\xca$\n\rGameRecording\x12\x85\x01\n\x1aGetAppsWithBackgroundVideo\x12\x32.CGameRecording_GetAppsWithBackgroundVideo_Request\x1a\x33.CGameRecording_GetAppsWithBackgroundVideo_Response\x12m\n\x12GetTimelinesForApp\x12*.CGameRecording_GetTimelinesForApp_Request\x1a+.CGameRecording_GetTimelinesForApp_Response\x12p\n\x13GetTimelinesForClip\x12+.CGameRecording_GetTimelinesForClip_Request\x1a,.CGameRecording_GetTimelinesForClip_Response\x12X\n\x0bQueryPhases\x12#.CGameRecording_QueryPhases_Request\x1a$.CGameRecording_QueryPhases_Response\x12L\n\x07GetTags\x12\x1f.CGameRecording_GetTags_Request\x1a .CGameRecording_GetTags_Response\x12m\n\x12GetEnoughDiskSpace\x12*.CGameRecording_GetEnoughDiskSpace_Request\x1a+.CGameRecording_GetEnoughDiskSpace_Response\x12v\n\x15GetAvailableDiskSpace\x12-.CGameRecording_GetAvailableDiskSpace_Request\x1a..CGameRecording_GetAvailableDiskSpace_Response\x12O\n\x08SaveClip\x12 .CGameRecording_SaveClip_Request\x1a!.CGameRecording_SaveClip_Response\x12U\n\nDeleteClip\x12\".CGameRecording_DeleteClip_Request\x1a#.CGameRecording_DeleteClip_Response\x12O\n\x08GetClips\x12 .CGameRecording_GetClips_Request\x1a!.CGameRecording_GetClips_Response\x12j\n\x11UploadClipToSteam\x12).CGameRecording_UploadClipToSteam_Request\x1a*.CGameRecording_UploadClipToSteam_Response\x12U\n\nExportClip\x12\".CGameRecording_ExportClip_Request\x1a#.CGameRecording_ExportClip_Response\x12j\n\x11\x45xportClipPreview\x12).CGameRecording_ExportClipPreview_Request\x1a*.CGameRecording_ExportClipPreview_Response\x12\x61\n\x0eTakeScreenshot\x12&.CGameRecording_TakeScreenshot_Request\x1a\'.CGameRecording_TakeScreenshot_Response\x12L\n\x07ZipClip\x12\x1f.CGameRecording_ZipClip_Request\x1a .CGameRecording_ZipClip_Response\x12\x61\n\x0eStartRecording\x12&.CGameRecording_StartRecording_Request\x1a\'.CGameRecording_StartRecording_Response\x12^\n\rStopRecording\x12%.CGameRecording_StopRecording_Request\x1a&.CGameRecording_StopRecording_Response\x12u\n\x1eGetBackgroundRecordingFileSize\x12(.CGameRecording_GetRecordingSize_Request\x1a).CGameRecording_GetRecordingSize_Response\x12\x88\x01\n\x1b\x43leanupBackgroundRecordings\x12\x33.CGameRecording_CleanupBackgroundRecordings_Request\x1a\x34.CGameRecording_CleanupBackgroundRecordings_Response\x12\x8b\x01\n\x1cGetAndTrimPostGameHighlights\x12\x34.CGameRecording_GetAndTrimPostGameHighlights_Request\x1a\x35.CGameRecording_GetAndTrimPostGameHighlights_Response\x12^\n\rGetThumbnails\x12%.CGameRecording_GetThumbnails_Request\x1a&.CGameRecording_GetThumbnails_Response\x12|\n\x17GetPlatformCapabilities\x12/.CGameRecording_GetPlatformCapabilities_Request\x1a\x30.CGameRecording_GetPlatformCapabilities_Response\x12W\n\x15NotifyTimelineChanged\x12,.CGameRecording_TimelineChanged_Notification\x1a\x10.WebUINoResponse\x12g\n\x1dNotifyRecordingSessionChanged\x12\x34.CGameRecording_RecordingSessionChanged_Notification\x1a\x10.WebUINoResponse\x12\x61\n\x1aNotifyTimelineEntryChanged\x12\x31.CGameRecording_TimelineEntryChanged_Notification\x1a\x10.WebUINoResponse\x12\x61\n\x1aNotifyTimelineEntryRemoved\x12\x31.CGameRecording_TimelineEntryRemoved_Notification\x1a\x10.WebUINoResponse\x12O\n\x11NotifyClipCreated\x12(.CGameRecording_ClipCreated_Notification\x1a\x10.WebUINoResponse\x12O\n\x11NotifyClipDeleted\x12(.CGameRecording_ClipDeleted_Notification\x1a\x10.WebUINoResponse\x12U\n\x14NotifyExportProgress\x12+.CGameRecording_ExportProgress_Notification\x1a\x10.WebUINoResponse\x12U\n\x14NotifyUploadProgress\x12+.CGameRecording_UploadProgress_Notification\x1a\x10.WebUINoResponse\x12Q\n\x12NotifyLowDiskSpace\x12).CGameRecording_LowDiskSpace_Notification\x1a\x10.WebUINoResponse\x12k\n\x1fNotifyPostGameHighlightsChanged\x12\x36.CGameRecording_PostGameHighlightsChanged_Notification\x1a\x10.WebUINoResponse\x12\x65\n\x1cNotifyOpenOverlayToGamePhase\x12\x33.CGameRecording_OpenOverlayToGamePhase_Notification\x1a\x10.WebUINoResponse\x12m\n NotifyOpenOverlayToTimelineEvent\x12\x37.CGameRecording_OpenOverlayToTimelineEvent_Notification\x1a\x10.WebUINoResponse\x12Y\n\x16NotifyPhaseListChanged\x12-.CGameRecording_PhaseListChanged_Notification\x1a\x10.WebUINoResponse\x12m\n\x12GetPerGameSettings\x12*.CGameRecording_GetPerGameSettings_Request\x1a+.CGameRecording_GetPerGameSettings_Response\x12m\n\x12SetPerGameSettings\x12*.CGameRecording_SetPerGameSettings_Request\x1a+.CGameRecording_SetPerGameSettings_Response\x12v\n\x15\x44\x65letePerGameSettings\x12-.CGameRecording_DeletePerGameSettings_Request\x1a..CGameRecording_DeletePerGameSettings_Response\x12s\n\x14UserAddTimelineEntry\x12,.CGameRecording_UserAddTimelineEntry_Request\x1a-.CGameRecording_UserAddTimelineEntry_Response\x12|\n\x17UserUpdateTimelineEntry\x12/.CGameRecording_UserUpdateTimelineEntry_Request\x1a\x30.CGameRecording_UserUpdateTimelineEntry_Response\x12|\n\x17UserRemoveTimelineEntry\x12/.CGameRecording_UserRemoveTimelineEntry_Request\x1a\x30.CGameRecording_UserRemoveTimelineEntry_Response\x12\x94\x01\n\x1fManuallyDeleteRecordingsForApps\x12\x37.CGameRecording_ManuallyDeleteRecordingsForApps_Request\x1a\x38.CGameRecording_ManuallyDeleteRecordingsForApps_Response\x12y\n\x16GetTotalDiskSpaceUsage\x12..CGameRecording_GetTotalDiskSpaceUsage_Request\x1a/.CGameRecording_GetTotalDiskSpaceUsage_Response\x12\x8e\x01\n\x1dSwitchBackgroundRecordingGame\x12\x35.CGameRecording_SwitchBackgroundRecordingGame_Request\x1a\x36.CGameRecording_SwitchBackgroundRecordingGame_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_gamerecording_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _GAMERECORDING._options = None
  _GAMERECORDING._serialized_options = b'\200\227\"\001'
  _ETIMELINEENTRYTYPE._serialized_start=9099
  _ETIMELINEENTRYTYPE._serialized_end=9473
  _EPHASERESULTTYPE._serialized_start=9475
  _EPHASERESULTTYPE._serialized_end=9585
  _ETIMELINECHANGENOTIFICATIONTYPE._serialized_start=9588
  _ETIMELINECHANGENOTIFICATIONTYPE._serialized_end=9930
  _ERECORDINGSESSIONCHANGENOTIFICATIONTYPE._serialized_start=9933
  _ERECORDINGSESSIONCHANGENOTIFICATIONTYPE._serialized_end=10194
  _EDISKSPACETYPE._serialized_start=10196
  _EDISKSPACETYPE._serialized_end=10271
  _ETHUMBNAILTIMEPRECISION._serialized_start=10273
  _ETHUMBNAILTIMEPRECISION._serialized_end=10328
  _ETHUMBNAILFORMAT._serialized_start=10330
  _ETHUMBNAILFORMAT._serialized_end=10373
  _CGAMERECORDING_GETAPPSWITHBACKGROUNDVIDEO_REQUEST._serialized_start=142
  _CGAMERECORDING_GETAPPSWITHBACKGROUNDVIDEO_REQUEST._serialized_end=193
  _CGAMERECORDING_GETAPPSWITHBACKGROUNDVIDEO_RESPONSE._serialized_start=196
  _CGAMERECORDING_GETAPPSWITHBACKGROUNDVIDEO_RESPONSE._serialized_end=556
  _CGAMERECORDING_GETAPPSWITHBACKGROUNDVIDEO_RESPONSE_APP._serialized_start=322
  _CGAMERECORDING_GETAPPSWITHBACKGROUNDVIDEO_RESPONSE_APP._serialized_end=556
  _CGAMERECORDING_GETTIMELINESFORAPP_REQUEST._serialized_start=558
  _CGAMERECORDING_GETTIMELINESFORAPP_REQUEST._serialized_end=618
  _CGAMERECORDING_GETTIMELINESFORAPP_RESPONSE._serialized_start=620
  _CGAMERECORDING_GETTIMELINESFORAPP_RESPONSE._serialized_end=716
  _CGAMERECORDING_GETTIMELINESFORCLIP_REQUEST._serialized_start=718
  _CGAMERECORDING_GETTIMELINESFORCLIP_REQUEST._serialized_end=779
  _CGAMERECORDING_GETTIMELINESFORCLIP_RESPONSE._serialized_start=782
  _CGAMERECORDING_GETTIMELINESFORCLIP_RESPONSE._serialized_end=936
  _CGAMERECORDING_QUERYPHASES_REQUEST._serialized_start=939
  _CGAMERECORDING_QUERYPHASES_REQUEST._serialized_end=1180
  _CGAMERECORDING_QUERYPHASES_REQUEST_TAG._serialized_start=1146
  _CGAMERECORDING_QUERYPHASES_REQUEST_TAG._serialized_end=1180
  _CGAMERECORDING_QUERYPHASES_RESPONSE._serialized_start=1183
  _CGAMERECORDING_QUERYPHASES_RESPONSE._serialized_end=1852
  _CGAMERECORDING_QUERYPHASES_RESPONSE_PHASE._serialized_start=1304
  _CGAMERECORDING_QUERYPHASES_RESPONSE_PHASE._serialized_end=1852
  _CGAMERECORDING_QUERYPHASES_RESPONSE_PHASE_BACKGROUNDRECORDING._serialized_start=1773
  _CGAMERECORDING_QUERYPHASES_RESPONSE_PHASE_BACKGROUNDRECORDING._serialized_end=1852
  _CGAMERECORDING_GETTAGS_REQUEST._serialized_start=1854
  _CGAMERECORDING_GETTAGS_REQUEST._serialized_end=1903
  _CGAMERECORDING_GETTAGS_RESPONSE._serialized_start=1905
  _CGAMERECORDING_GETTAGS_RESPONSE._serialized_end=1967
  _CGAMERECORDING_GETENOUGHDISKSPACE_REQUEST._serialized_start=1969
  _CGAMERECORDING_GETENOUGHDISKSPACE_REQUEST._serialized_end=2012
  _CGAMERECORDING_GETENOUGHDISKSPACE_RESPONSE._serialized_start=2014
  _CGAMERECORDING_GETENOUGHDISKSPACE_RESPONSE._serialized_end=2080
  _CGAMERECORDING_GETAVAILABLEDISKSPACE_REQUEST._serialized_start=2082
  _CGAMERECORDING_GETAVAILABLEDISKSPACE_REQUEST._serialized_end=2128
  _CGAMERECORDING_GETAVAILABLEDISKSPACE_RESPONSE._serialized_start=2130
  _CGAMERECORDING_GETAVAILABLEDISKSPACE_RESPONSE._serialized_end=2191
  _CGAMERECORDING_TIMELINECHANGED_NOTIFICATION._serialized_start=2194
  _CGAMERECORDING_TIMELINECHANGED_NOTIFICATION._serialized_end=2422
  _CGAMERECORDING_RECORDINGSESSIONCHANGED_NOTIFICATION._serialized_start=2425
  _CGAMERECORDING_RECORDINGSESSIONCHANGED_NOTIFICATION._serialized_end=2774
  _CTIMELINEENTRY._serialized_start=2777
  _CTIMELINEENTRY._serialized_end=3240
  _CGAMERECORDING_TIMELINEENTRYCHANGED_NOTIFICATION._serialized_start=3242
  _CGAMERECORDING_TIMELINEENTRYCHANGED_NOTIFICATION._serialized_end=3341
  _CGAMERECORDING_TIMELINEENTRYREMOVED_NOTIFICATION._serialized_start=3343
  _CGAMERECORDING_TIMELINEENTRYREMOVED_NOTIFICATION._serialized_end=3449
  _CGAMERECORDING_LOWDISKSPACE_NOTIFICATION._serialized_start=3451
  _CGAMERECORDING_LOWDISKSPACE_NOTIFICATION._serialized_end=3493
  _CGAMERECORDING_POSTGAMEHIGHLIGHTSCHANGED_NOTIFICATION._serialized_start=3495
  _CGAMERECORDING_POSTGAMEHIGHLIGHTSCHANGED_NOTIFICATION._serialized_end=3567
  _CGAMERECORDING_OPENOVERLAYTOGAMEPHASE_NOTIFICATION._serialized_start=3569
  _CGAMERECORDING_OPENOVERLAYTOGAMEPHASE_NOTIFICATION._serialized_end=3656
  _CGAMERECORDING_OPENOVERLAYTOTIMELINEEVENT_NOTIFICATION._serialized_start=3658
  _CGAMERECORDING_OPENOVERLAYTOTIMELINEEVENT_NOTIFICATION._serialized_end=3749
  _CGAMERECORDING_PHASELISTCHANGED_NOTIFICATION._serialized_start=3751
  _CGAMERECORDING_PHASELISTCHANGED_NOTIFICATION._serialized_end=3797
  _CGAMERECORDING_CLIPSUMMARY._serialized_start=3800
  _CGAMERECORDING_CLIPSUMMARY._serialized_end=4220
  _CGAMERECORDING_SAVECLIP_REQUEST._serialized_start=4223
  _CGAMERECORDING_SAVECLIP_REQUEST._serialized_end=4518
  _CGAMERECORDING_SAVECLIP_REQUEST_POSITION._serialized_start=4468
  _CGAMERECORDING_SAVECLIP_REQUEST_POSITION._serialized_end=4518
  _CGAMERECORDING_SAVECLIP_RESPONSE._serialized_start=4520
  _CGAMERECORDING_SAVECLIP_RESPONSE._serialized_end=4600
  _CGAMERECORDING_DELETECLIP_REQUEST._serialized_start=4602
  _CGAMERECORDING_DELETECLIP_REQUEST._serialized_end=4654
  _CGAMERECORDING_DELETECLIP_RESPONSE._serialized_start=4656
  _CGAMERECORDING_DELETECLIP_RESPONSE._serialized_end=4692
  _CGAMERECORDING_EXPORTCLIP_SETTINGS._serialized_start=4695
  _CGAMERECORDING_EXPORTCLIP_SETTINGS._serialized_end=4865
  _CGAMERECORDING_EXPORTCLIP_REQUEST._serialized_start=4868
  _CGAMERECORDING_EXPORTCLIP_REQUEST._serialized_end=5029
  _CGAMERECORDING_EXPORTCLIP_RESPONSE._serialized_start=5031
  _CGAMERECORDING_EXPORTCLIP_RESPONSE._serialized_end=5067
  _CGAMERECORDING_EXPORTCLIPPREVIEW_REQUEST._serialized_start=5070
  _CGAMERECORDING_EXPORTCLIPPREVIEW_REQUEST._serialized_end=5211
  _CGAMERECORDING_EXPORTCLIPPREVIEW_RESPONSE._serialized_start=5213
  _CGAMERECORDING_EXPORTCLIPPREVIEW_RESPONSE._serialized_end=5335
  _CGAMERECORDING_TAKESCREENSHOT_REQUEST._serialized_start=5337
  _CGAMERECORDING_TAKESCREENSHOT_REQUEST._serialized_end=5442
  _CGAMERECORDING_TAKESCREENSHOT_RESPONSE._serialized_start=5444
  _CGAMERECORDING_TAKESCREENSHOT_RESPONSE._serialized_end=5507
  _CGAMERECORDING_UPLOADCLIPTOSTEAM_REQUEST._serialized_start=5509
  _CGAMERECORDING_UPLOADCLIPTOSTEAM_REQUEST._serialized_end=5617
  _CGAMERECORDING_UPLOADCLIPTOSTEAM_RESPONSE._serialized_start=5619
  _CGAMERECORDING_UPLOADCLIPTOSTEAM_RESPONSE._serialized_end=5708
  _CGAMERECORDING_ZIPCLIP_REQUEST._serialized_start=5710
  _CGAMERECORDING_ZIPCLIP_REQUEST._serialized_end=5759
  _CGAMERECORDING_ZIPCLIP_RESPONSE._serialized_start=5761
  _CGAMERECORDING_ZIPCLIP_RESPONSE._serialized_end=5812
  _CGAMERECORDING_GETCLIPS_REQUEST._serialized_start=5814
  _CGAMERECORDING_GETCLIPS_REQUEST._serialized_end=5914
  _CGAMERECORDING_GETCLIPS_RESPONSE._serialized_start=5916
  _CGAMERECORDING_GETCLIPS_RESPONSE._serialized_end=5993
  _CGAMERECORDING_GETANDTRIMPOSTGAMEHIGHLIGHTS_REQUEST._serialized_start=5995
  _CGAMERECORDING_GETANDTRIMPOSTGAMEHIGHLIGHTS_REQUEST._serialized_end=6088
  _CGAMERECORDING_GETANDTRIMPOSTGAMEHIGHLIGHTS_RESPONSE._serialized_start=6090
  _CGAMERECORDING_GETANDTRIMPOSTGAMEHIGHLIGHTS_RESPONSE._serialized_end=6190
  _CGAMERECORDING_USERADDTIMELINEENTRY_REQUEST._serialized_start=6192
  _CGAMERECORDING_USERADDTIMELINEENTRY_REQUEST._serialized_end=6303
  _CGAMERECORDING_USERADDTIMELINEENTRY_RESPONSE._serialized_start=6305
  _CGAMERECORDING_USERADDTIMELINEENTRY_RESPONSE._serialized_end=6369
  _CGAMERECORDING_USERUPDATETIMELINEENTRY_REQUEST._serialized_start=6371
  _CGAMERECORDING_USERUPDATETIMELINEENTRY_REQUEST._serialized_end=6485
  _CGAMERECORDING_USERUPDATETIMELINEENTRY_RESPONSE._serialized_start=6487
  _CGAMERECORDING_USERUPDATETIMELINEENTRY_RESPONSE._serialized_end=6536
  _CGAMERECORDING_USERREMOVETIMELINEENTRY_REQUEST._serialized_start=6538
  _CGAMERECORDING_USERREMOVETIMELINEENTRY_REQUEST._serialized_end=6659
  _CGAMERECORDING_USERREMOVETIMELINEENTRY_RESPONSE._serialized_start=6661
  _CGAMERECORDING_USERREMOVETIMELINEENTRY_RESPONSE._serialized_end=6710
  _CGAMERECORDING_MANUALLYDELETERECORDINGSFORAPPS_REQUEST._serialized_start=6712
  _CGAMERECORDING_MANUALLYDELETERECORDINGSFORAPPS_REQUEST._serialized_end=6786
  _CGAMERECORDING_MANUALLYDELETERECORDINGSFORAPPS_RESPONSE._serialized_start=6788
  _CGAMERECORDING_MANUALLYDELETERECORDINGSFORAPPS_RESPONSE._serialized_end=6845
  _CGAMERECORDING_GETTOTALDISKSPACEUSAGE_REQUEST._serialized_start=6847
  _CGAMERECORDING_GETTOTALDISKSPACEUSAGE_REQUEST._serialized_end=6974
  _CGAMERECORDING_GETTOTALDISKSPACEUSAGE_RESPONSE._serialized_start=6976
  _CGAMERECORDING_GETTOTALDISKSPACEUSAGE_RESPONSE._serialized_end=7038
  _CGAMERECORDING_GETTHUMBNAILS_REQUEST._serialized_start=7041
  _CGAMERECORDING_GETTHUMBNAILS_REQUEST._serialized_end=7295
  _CGAMERECORDING_GETTHUMBNAILS_RESPONSE._serialized_start=7298
  _CGAMERECORDING_GETTHUMBNAILS_RESPONSE._serialized_end=7471
  _CGAMERECORDING_GETTHUMBNAILS_RESPONSE_THUMBNAIL._serialized_start=7409
  _CGAMERECORDING_GETTHUMBNAILS_RESPONSE_THUMBNAIL._serialized_end=7471
  _CGAMERECORDING_STARTRECORDING_REQUEST._serialized_start=7473
  _CGAMERECORDING_STARTRECORDING_REQUEST._serialized_end=7529
  _CGAMERECORDING_STARTRECORDING_RESPONSE._serialized_start=7531
  _CGAMERECORDING_STARTRECORDING_RESPONSE._serialized_end=7571
  _CGAMERECORDING_STOPRECORDING_REQUEST._serialized_start=7573
  _CGAMERECORDING_STOPRECORDING_REQUEST._serialized_end=7628
  _CGAMERECORDING_STOPRECORDING_RESPONSE._serialized_start=7630
  _CGAMERECORDING_STOPRECORDING_RESPONSE._serialized_end=7715
  _CGAMERECORDING_GETRECORDINGSIZE_REQUEST._serialized_start=7717
  _CGAMERECORDING_GETRECORDINGSIZE_REQUEST._serialized_end=7775
  _CGAMERECORDING_GETRECORDINGSIZE_RESPONSE._serialized_start=7777
  _CGAMERECORDING_GETRECORDINGSIZE_RESPONSE._serialized_end=7838
  _CGAMERECORDING_CLEANUPBACKGROUNDRECORDINGS_REQUEST._serialized_start=7840
  _CGAMERECORDING_CLEANUPBACKGROUNDRECORDINGS_REQUEST._serialized_end=7892
  _CGAMERECORDING_CLEANUPBACKGROUNDRECORDINGS_RESPONSE._serialized_start=7894
  _CGAMERECORDING_CLEANUPBACKGROUNDRECORDINGS_RESPONSE._serialized_end=7947
  _CGAMERECORDING_GETPLATFORMCAPABILITIES_REQUEST._serialized_start=7949
  _CGAMERECORDING_GETPLATFORMCAPABILITIES_REQUEST._serialized_end=7997
  _CGAMERECORDING_GETPLATFORMCAPABILITIES_RESPONSE._serialized_start=7999
  _CGAMERECORDING_GETPLATFORMCAPABILITIES_RESPONSE._serialized_end=8083
  _CGAMERECORDING_CLIPCREATED_NOTIFICATION._serialized_start=8085
  _CGAMERECORDING_CLIPCREATED_NOTIFICATION._serialized_end=8172
  _CGAMERECORDING_CLIPDELETED_NOTIFICATION._serialized_start=8174
  _CGAMERECORDING_CLIPDELETED_NOTIFICATION._serialized_end=8249
  _CGAMERECORDING_EXPORTPROGRESS_NOTIFICATION._serialized_start=8251
  _CGAMERECORDING_EXPORTPROGRESS_NOTIFICATION._serialized_end=8347
  _CGAMERECORDING_PERGAMESETTINGS._serialized_start=8349
  _CGAMERECORDING_PERGAMESETTINGS._serialized_end=8466
  _CGAMERECORDING_GETPERGAMESETTINGS_REQUEST._serialized_start=8468
  _CGAMERECORDING_GETPERGAMESETTINGS_REQUEST._serialized_end=8511
  _CGAMERECORDING_GETPERGAMESETTINGS_RESPONSE._serialized_start=8513
  _CGAMERECORDING_GETPERGAMESETTINGS_RESPONSE._serialized_end=8608
  _CGAMERECORDING_SETPERGAMESETTINGS_REQUEST._serialized_start=8610
  _CGAMERECORDING_SETPERGAMESETTINGS_REQUEST._serialized_end=8709
  _CGAMERECORDING_SETPERGAMESETTINGS_RESPONSE._serialized_start=8711
  _CGAMERECORDING_SETPERGAMESETTINGS_RESPONSE._serialized_end=8755
  _CGAMERECORDING_DELETEPERGAMESETTINGS_REQUEST._serialized_start=8757
  _CGAMERECORDING_DELETEPERGAMESETTINGS_REQUEST._serialized_end=8819
  _CGAMERECORDING_DELETEPERGAMESETTINGS_RESPONSE._serialized_start=8821
  _CGAMERECORDING_DELETEPERGAMESETTINGS_RESPONSE._serialized_end=8868
  _CGAMERECORDING_UPLOADPROGRESS_NOTIFICATION._serialized_start=8870
  _CGAMERECORDING_UPLOADPROGRESS_NOTIFICATION._serialized_end=8966
  _CGAMERECORDING_SWITCHBACKGROUNDRECORDINGGAME_REQUEST._serialized_start=8968
  _CGAMERECORDING_SWITCHBACKGROUNDRECORDINGGAME_REQUEST._serialized_end=9039
  _CGAMERECORDING_SWITCHBACKGROUNDRECORDINGGAME_RESPONSE._serialized_start=9041
  _CGAMERECORDING_SWITCHBACKGROUNDRECORDINGGAME_RESPONSE._serialized_end=9096
  _GAMERECORDING._serialized_start=10376
  _GAMERECORDING._serialized_end=15058
_builder.BuildServices(DESCRIPTOR, 'webuimessages_gamerecording_pb2', globals())
# @@protoc_insertion_point(module_scope)
